<?php
/**
 * The admin integrations page functionality of the plugin.
 *
 * @link       https://themehigh.com
 * @since      1.0.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_Admin_Settings_Integrations')):

class THWEC_Admin_Settings_Integrations{
	/**
	 * Main instance of the class
	 *
	 * @access   protected
	 * @var      $_instance    
	 */
	protected static $_instance = null;
	
	/**
	 * Stores the plugin template settings
	 *
	 * @access   private
	 * @var      $db_settings    template settings
	 */
	private $db_settings = array();

	/**
	 * Manages the list of compatible third party plugins
	 *
	 * @access   private
	 * @var      $plugin_list    list of plugins
	 */
	private $plugin_list = array();

	/**
	 * Manages the list of compatible third party plugins
	 *
	 * @access   private
	 * @var      $plugin_list    list of plugins
	 */
	private $future_compatible = array();

	/**
	 * Whether the integration settings saved in db or not
	 *
	 * @access   private
	 * @var      $result    boolean saved in db or not
	 */
	private $result = null;

	/**
	 * website urls of the compatible third party plugins
	 *
	 * @access   private
	 * @var      $plugin_urls    array website urls
	 */
	private $plugin_urls = null;

	/**
	 * Construct
	 */
	public function __construct() {
		$this->save_integrations();
		$this->init_helpers();
	}
	
	/**
	 * Main THWEC_Admin_Template_Mapping Instance.
	 *
	 * Ensures only one instance of THWEC_Admin_Template_Mapping is loaded or can be loaded.
	 *
	 * @since 3.5.0
	 * @static
	 * @return THWEC_Admin_Template_Mapping Main instance
	 */
	public static function instance() {
		if(is_null(self::$_instance)){
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	private function save_integrations(){
		if(isset($_POST['save_thwec_integrations']) || isset($_POST['reset_thwec_integrations'])){
			if ( ! isset( $_POST['thwec_integration_settings_form'] )  || ! wp_verify_nonce( $_POST['thwec_integration_settings_form'], 'thwec_integrations_actions' ) ){
	   				print __('Sorry, your nonce did not verify.', 'woocommerce-email-customizer');
   				exit;
			}
			$integrations = array();
			$settings = THWEC_Utils::get_template_settings();
			$plugins = $this->get_default_integrations();
			foreach ($plugins as $key => $plugin) {
				if( isset($_POST['thwec_integration_'.$key]) ){
					if( isset($_POST['save_thwec_integrations']) ){
						$integrations[$key] = THWEC_Utils::validate_boolean($_POST['thwec_integration_'.$key]);
					}else if( isset($_POST['reset_thwec_integrations']) ){
						$integrations[$key] = $this->is_integration_plugin_active($key) ? true : false;
					}
				}
			}
			$compatibility_settings = isset($settings['compatibility_settings']) ? $settings['compatibility_settings'] : array();
			$settings['compatibility_settings'] = apply_filters('thwec_set_compatibility_settings', $compatibility_settings);
			$settings['integrations'] = $integrations;
			$this->result = THWEC_Utils::save_template_settings($settings);
		}
	}

	private function init_helpers(){
		$this->db_settings = THWEC_Utils::get_template_settings();
		$this->plugin_list = $this->get_compatible_plugins();
		$this->integrations = $this->get_integrations();
		$this->plugin_urls = array(
			'wpml'					=>	'https://wpml.org/',
			'ywgc'					=>	'https://yithemes.com/themes/plugins/yith-woocommerce-gift-cards/',
			'wosm'					=>	'https://woocommerce.com/products/woocommerce-order-status-manager/',
			'cwginstocknotifier'	=>	'https://wordpress.org/plugins/back-in-stock-notifier-for-woocommerce/',
			'wcb2b'					=>	'https://woocommerce-b2b.com/'
		);
	}

	private function get_integrations(){
		$integrations = isset($this->db_settings['integrations']) ? $this->db_settings['integrations'] : false;
		if( !$integrations ){
			$integrations = $this->get_default_integrations();
		}
		return $integrations;
	}

	public function render_page(){
		?>
		<div class="thwec-integrations-wrapper wrap">
			<h1>Integrations</h1>
			<?php if( !is_null($this->result) ){
				$this->render_notifications();
			} ?>
			<div class="thwec-integration-popup">
				<div class="thwec-integration-popup-content">
				</div>
			</div>
			<form name="manage_wecm_integrations" action="" method="POST">
				<?php if ( function_exists('wp_nonce_field') ){
					wp_nonce_field( 'thwec_integrations_actions', 'thwec_integration_settings_form' ); 
				} ?>
				<div class="thwec-integrations">
					<div class="thwec-integration-action-buttons">
						<button type="submit"class="button" name="reset_thwec_integrations" id="reset_thwec_integrations">Reset Changes</button>
						<button type="submit" class="button button-primary" name="save_thwec_integrations">Save Changes</button>
					</div>
					<div class="thwecm-integration-browser content-filterable rendered">
						<div class="thwecm-integrations wp-clearfix">
							<?php foreach ($this->plugin_list as $key => $plugin) { 
								$is_active = $this->is_integration_plugin_active($key);
								$checked = isset($this->integrations[$key]) ? $this->integrations[$key] : false;
								$checked = $checked ? "checked" : '';
								$settings_icon_url = $this->get_settings_icon_url($is_active);
								$plugin_url = isset( $this->plugin_urls[$key] ) ? $this->plugin_urls[$key] : '';
								?>
								<div class="thwec-integration thwecm-integration thwec-integration-<?php echo $key; ?> <?php echo !$is_active ? "thwec-plugin-deactive" : ""; ?>" data-icon="<?php echo esc_attr($this->get_icon_url($key)); ?>" data-plugin-url="<?php echo esc_url(admin_url('plugins.php')); ?>" data-title="<?php echo esc_attr($plugin['name']); ?>">
									<div class="thwec-integration-content">
										<p class="thwec-integration-title thwec-label"><?php echo esc_html($plugin['name']); ?></p>
										<?php $this->integration_settings_page_navigator($is_active, $key, $settings_icon_url); ?>
										<?php if(!$is_active){
											echo '<p class="thwec-integration-inactive-label">Inactive</p>';
										} ?>
									</div>
									<div class="thwec-integration-footer">
										<a href="<?php echo $plugin_url; ?>" target="_blank"><img src="<?php echo THWEC_ASSETS_URL_ADMIN.$this->get_icon_url($key); ?>"></a>
										<?php if($checked && !$is_active){
											echo '<img src="'.THWEC_ASSETS_URL_ADMIN.'/images/integrations/warning.svg" class="thwec-integration-warning" />';
										}
										?> 
										<label class="<?php echo $this->get_switch_class($is_active, $checked); ?>">
											<input type="hidden" name="thwec_integration_<?php echo esc_attr($key); ?>" value="<?php echo $checked ? true : false; ?>">
											<input type="checkbox" name="thwec_integration_cb_<?php echo esc_attr($key); ?>" class="thwec-integration-switch" data-integration="<?php echo esc_attr($key); ?>" <?php echo $checked; ?> />
											<span class="slider round"></span>
										</label>
									</div>
								</div>
							<?php } ?>
						</div>
					</div>
					<div class="clear-float"></div>
				</div>
			</form>
		</div>
		<?php
	}

	private function get_switch_class($is_active, $checked){
		$class = 'switch';
		if( $checked && !$is_active ){
			$class .= ' thwec-integration-plugin-inactive';
		}else if( !$is_active ){
			$class .= ' thwec-switch-popup';
		}
		return $class;
	}

	private function integration_settings_page_navigator($is_active, $plugin, $icon_url){
		$url = false;
		if( $is_active ){
			$url = $this->get_settings_url($plugin);
		}
		if( $url ){
			echo '<a href="'.esc_url($this->get_settings_url($plugin)).'" target="'.esc_attr($plugin).'"><img src="'.THWEC_ASSETS_URL_ADMIN.$icon_url.'"></a>';
		}else{
			echo '<img src="'.THWEC_ASSETS_URL_ADMIN.$icon_url.'">';
		}
	}

	private function get_compatible_plugins(){
		return array(
			'wpml'	=>	array(
				'name'		=>	'WPML',
				'author'	=>	'OnTheGoSystems',
			),
			'ywgc'	=>	array(
				'name'		=>	'YITH WooCommerce Gift Cards(Pro)',
				'author'	=>	'YITH',
			),
			'wosm'	=>	array(
				'name'		=>	'WooCommerce Order Status Manager',
				'author'	=>	'SkyVerge',
			),
			'cwginstocknotifier'	=>	array(
				'name'		=>	'Back In Stock Notifier for WooCommerce',
				'author'	=>	'codewoogeek',
			),
			'wcb2b'	=>	array(
				'name'		=>	'WooCommerce B2B',
				'author'	=>	'Code4Life',
			),
		);
	}

	private function get_default_integrations(){
		$compatible_plugins = array();
		$plugins = $this->get_compatible_plugins();
		foreach ($plugins as $key => $plugin) {
			$active = $this->is_integration_plugin_active($key);
			$compatible_plugins[$key] =  $active ? true : false;
		}
		return $compatible_plugins;
	}

	private function is_integration_plugin_active($plugin){
		if( $plugin == "wpml" ){
			return THWEC_Utils::is_wpml_active();

		}else if( $plugin == "ywgc" ){
			return THWEC_Utils::is_ywgc_active();

		}else if( $plugin == "wosm" ){
			return THWEC_Utils::is_order_status_manager_active();

		}else if( $plugin == "cwginstocknotifier" ){
			return THWEC_Utils::is_back_in_stock_notifier_active();

		}else if( $plugin == "wcb2b" ){
			return THWEC_Utils::is_woocommerce_b2b_active();
		}
		return false;
	}

	private function render_notifications(){
		if( $this->result ){
			$result = "success";
			$message = "Saved changes.";
		}else{
			$result = "error";
			$message = "Your changes were not saved due to an error (or you made none!).";
		}
		if( isset($_POST['reset_thwec_integrations']) ){
			$message = $result == "success" ? "Settings reset successfully." : "Settings not reset due to an error (or nothing to reset).";
		}
		?>
		<div id="thwec_validations" class="thwec-integration-validation thwec-<?php echo $result; ?>">
		    <p class="thwec-label"><?php echo $message; ?></p>
        </div>
        <script>
        	jQuery(function($) {
        		setTimeout(function() { $("#thwec_validations").remove(); }, 2000);
        	});
        </script>
        <?php
	}

	private function get_settings_icon_url($is_active){
		return !$is_active ? 'images/settings-deactive.svg' : 'images/settings.svg';
	}

	private function get_icon_url($plugin){
		return 'images/integrations/'.$plugin.'.svg';
	}

	private function get_settings_url($plugin){
		if( $plugin == "wpml" ){
			return admin_url('admin.php?page=sitepress-multilingual-cms/menu/languages.php');

		}else if( $plugin == "ywgc" ){
			return admin_url('admin.php?page=yith_woocommerce_gift_cards_panel');

		}else if( $plugin == "wosm" ){
			return admin_url('edit.php?post_type=wc_order_status');

		}else if( $plugin == "cwginstocknotifier" ){
			return admin_url('edit.php?post_type=cwginstocknotifier&page=cwg-instock-mailer');

		}else if( $plugin == "wcb2b" ){
			return admin_url('admin.php?page=wc-settings&tab=woocommerce-b2b');
		}
		return false;
	}
	
}

endif;