<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themehigh.com
 * @since      1.0.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_Admin')):
 
class THWEC_Admin {
	/**
	 * Name of the plugin
	 *
	 * @access   private
	 * @var      $plugin_name    The string used to uniquely identify this plugin.
	 */
	private $plugin_name;

	/**
	 * Version of the plugin
	 *
	 * @access   private
	 * @var      $version    The string used to identify version of this plugin.
	 */
	private $version;

	/**
	 * The class instance responsible for template saving functionality
	 *
	 * @access   public
	 * @var      $general_instance    The general class instance
	 */
	public $general_instance = null;

	/**
	 * The class instance responsible for import export functionality
	 *
	 * @access   public
	 * @var      $migrate_instance    Import export class instance
	 */
	public $migrate_instance = null;

	/**
	 * The array of plugin pages that are required for loading styles and scripts
	 *
	 * @access   private
	 * @var      $plugin_pages    array of plugin pages
	 */
	private $plugin_pages;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->plugin_pages = array(
			'toplevel_page_th_email_customizer_templates',
			'email-customizer_page_th_email_customizer_pro',
			'email-customizer_page_th_email_customizer_mapping',
			'email-customizer_page_th_email_customizer_react',
			'email-customizer_page_th_email_customizer_integrations'
		);
		add_action('wp_ajax_thwec_close_feature_popup', array($this,'close_feature_popup'));
	}

	/**
	 * Prepare instance of classes required for ajax requests
	 */
	public function prepare_ajax_queues(){
		if( THWEC_Utils::thwec_actions() && THWEC_Utils::is_ajax_query() ){
			$this->general_instance = THWEC_Admin_Settings_General::instance();
		}
		
		if( THWEC_Utils::is_migrate_action( false, true ) && is_null( $this->migrate_instance ) ){
			$this->migrate_instance = THWEC_Utils::get_migrate_instance();
		}
		
	}

	/**
	 * Redirects the user after plugin activation.
	 */
	function thwec_activation_redirect() {
		// Make sure it's the correct user
		if ( !wp_doing_ajax() && intval( get_option( 'thwec_activation_redirect', false ) ) === wp_get_current_user()->ID ) {
			// Make sure we don't redirect again after this one
			delete_option( 'thwec_activation_redirect' );
			wp_safe_redirect( admin_url( '/?page=th_email_customizer_templates' ) );
			exit;
		}
	}
	
	/**
	 * Common function to enqueue admin styles and scripts
	 *
	 * @param   string   $hook   current admin page
	 */
	public function enqueue_styles_and_scripts( $hook ) {
		$debug_mode = apply_filters('thwec_debug_mode', false);
		$suffix = $debug_mode ? '' : '.min';

		if( $hook == "email-customizer_page_th_email_customizer_license_settings" ){
			wp_enqueue_style('thwec-admin-style', THWEC_ASSETS_URL_ADMIN . 'css/thwec-admin'. $suffix .'.css', array(), $this->version);
		}
		if(!in_array($hook, $this->plugin_pages)){
			return;
		}
		
		$this->enqueue_scripts( $hook, $suffix);
		$this->enqueue_styles($suffix);
		wp_enqueue_media();
	}

	/**
	 * enqueue admin styles
	 *
	 * @param   string   $suffix   load minified or unminified file
	 */
	private function enqueue_styles($suffix) {
		wp_enqueue_style('jquery-ui-style', '//code.jquery.com/ui/1.11.4/themes/smoothness/jquery-ui.css?ver=1.11.4');
		wp_enqueue_style('woocommerce_admin_styles', THWEC_WOO_ASSETS_URL.'css/admin.css');
		wp_enqueue_style('wp-color-picker');
		wp_enqueue_style('thwec-admin-style', THWEC_ASSETS_URL_ADMIN . 'css/thwec-admin'. $suffix .'.css', array(), $this->version);
		wp_enqueue_style('roboto-style','https://fonts.googleapis.com/css2?family=Roboto:wght@300;500;700&display=swap');
		wp_enqueue_style('wp-codemirror');
	}

	/**
	 * enqueue admin scripts
	 *
	 * @param string  $suffix  load minified or unminified file
	 */
	private function enqueue_scripts( $hook, $suffix ) {
		$script_var = array(
			'admin_url' => admin_url(),
            'ajaxurl'   => admin_url( 'admin-ajax.php' ),
            'admin_plugin_url' => THWEC_ASSETS_URL_ADMIN,
            'page_id' => isset( $_GET['page'] ) ? sanitize_text_field( $_GET['page'] ) : '',
            'initialize_builder' => wp_create_nonce( 'thwec-initialize-builder' ),
            'editing' => isset( $_POST['i_template_name'] ) ? 1 : (isset( $_POST['thwec_template_lang'] ) ? 1 : 0),
            'close_feature_popup' => wp_create_nonce( 'close-feature-popup' ),
            'page_hook' => $hook
		);
		$template_filter = apply_filters('thwec_wpml_template_list_filter', true );
		$cm_settings['TestEditor'] = wp_enqueue_code_editor(array(
			'type' => 'text/css', 
			'gutters' => ['CodeMirror-lint-markers'],
			'lint' => true
			)
		);
		$deps = array('jquery', 'jquery-ui-core', 'jquery-ui-draggable', 'jquery-ui-droppable', 'jquery-ui-sortable','jquery-ui-resizable', 'jquery-ui-widget', 'jquery-ui-tabs','jquery-tiptip', 'woocommerce_admin', 'wc-enhanced-select', 'select2', 'wp-color-picker','select2');
		
		if( $hook === 'email-customizer_page_th_email_customizer_pro' ){
			wp_enqueue_script( 'thwec-admin-script', THWEC_ASSETS_URL_ADMIN . 'js/thwec-editor'. $suffix .'.js', ['wp-element', 'jquery'], $this->version, true );
			$script_var = array_merge( $script_var, array(
				'add_css_feature'	=> true,
	            'cm_settings'		=> $cm_settings,
	            'save_temp_on_settings'	=> apply_filters('thwec_enable_template_save_on_settings_change', false),
	            'save_nonce'	=> wp_create_nonce( 'thwec-save-settings' ),
	            'preview_order' => wp_create_nonce( 'thwec-preview-order' ),
	          
	            'woo_orders' => $this->get_woo_orders(),
	           	'woo_emails' => $this->get_woo_email_instances(),
	            'template' => $this->get_template_details(),
	            'bloginfo' => get_bloginfo(),
	            'woo_currency_symbol' => get_woocommerce_currency_symbol(),
	            'builder_url' => THWEC_Utils::get_admin_url(),
	            'testmail_recepient' => apply_filters('thwecm_set_testmail_recepient', true) ? THWEC_Admin_Utils::get_logged_in_user_email() : "",
	            'allowed_tags' => apply_filters('thwec_set_allowed_tags_in_text', ['b', 'strong', 'u', 'i', 'a'])
	        ));

			$script_var['remove_unencoded_html'] = $this->should_remove_unencoded( $script_var );
		}else{
			wp_enqueue_script( 'thwec-admin-script', THWEC_ASSETS_URL_ADMIN . 'js/thwec-admin'. $suffix .'.js', $deps, $this->version, false );
			$script_var =  array_merge( $script_var, array(
	            'template_filter'		=> (int) $template_filter,
	            'export_nonce' 			=> wp_create_nonce( 'thwec-settings-export' ),
	            'import_nonce' 			=> wp_create_nonce( 'thwec-settings-import' ),
	            'upload_folder_info'	=>	THWEC_Utils::get_uploads_folder_info()
        	));
		}
		wp_enqueue_script( 'thwec-admin-misc', THWEC_ASSETS_URL_ADMIN . 'misc_js/thwec-admin-misc.min.js', $deps, $this->version, false );
		$script_data = apply_filters('thwec_get_script_data', array(), $hook);
		$script_var = is_array($script_data) ? array_merge($script_data, $script_var) : $script_var;
		wp_localize_script('thwec-admin-script', 'thwec_var', $script_var);
	}

	private function should_remove_unencoded( $template ){
		$remove = false;
		if( isset( $template['template']['remove_unencoded'] ) && !empty($template['template']['remove_unencoded'] ) ) {
			$remove = $template['template']['remove_unencoded'];
		}
		return apply_filters('thwecmf_remove_template_json_html', $remove);
	}

	/**
	 * Collapse the wordpress sidebar menu
	 */
	public function collapse_admin_sidebar(){
		$page = isset( $_GET['page'] ) ? $_GET['page'] : false;
		if( $page && $page == 'th_email_customizer_pro' ){
			if( get_user_setting('mfold') != 'f' ){
				set_user_setting('mfold', 'f');
			}
		}else{
			set_user_setting('mfold', 'o');
		}
	}

	/**
	 * Collapse the wordpress sidebar menu
	 */
	public function prepare_preview(){
		$preview = THWEC_Utils::is_preview();
		$order_id = isset( $_GET['id'] ) ? sanitize_key( base64_decode( $_GET['id'] ) ) : false;
		$email = isset( $_GET['email'] ) ? sanitize_text_field( base64_decode( $_GET['email'] ) ) : false;
		$ywgc_email = isset( $_GET['ywgc_email'] ) && !empty( $_GET['ywgc_email'] ) ? sanitize_text_field( base64_decode( $_GET['ywgc_email'] ) ) : false;
		
		if( $preview ){
			$general = THWEC_Admin_Settings_General::instance();
			$content = $general->thwec_order_preview( $order_id, $email, $ywgc_email, $preview, false, true, true );
			$general->load_preview( $content );
			die;
		}
	}

	/**
	 * Add plugin menu to Wordpress sidebar menu
	 */
	public function admin_menu() {
		$manage_cap = THWEC_Utils::is_allowed_menu_cap( apply_filters('thwec_manage_plugin_menu_capability', 'manage_woocommerce') );
		$menu_pos = THWEC_Utils::is_a_menu_position( apply_filters( 'thwec_admin_menu_position', 56 ) );
		$this->screen_id = add_menu_page(  THWEC_i18n::t('Email Customizer'), THWEC_i18n::t('Email Customizer'), $manage_cap, 'th_email_customizer_templates', array($this, 'output_settings'), 'dashicons-admin-customizer', $menu_pos );
		$this->screen_id .= add_submenu_page('th_email_customizer_templates', THWEC_i18n::t('Templates'), THWEC_i18n::t('Templates'), $manage_cap, 'th_email_customizer_templates', array($this, 'output_settings'));
		$this->screen_id .= add_submenu_page('th_email_customizer_templates', THWEC_i18n::t('Email Mapping'), THWEC_i18n::t('Email Mapping'), $manage_cap, 'th_email_customizer_mapping', array($this, 'output_settings'));
		$this->screen_id .= add_submenu_page('th_email_customizer_templates', THWEC_i18n::t('Add New'), THWEC_i18n::t('Add New'), $manage_cap, 'th_email_customizer_pro', array($this, 'output_settings'));
		$this->screen_id .= add_submenu_page('th_email_customizer_templates', THWEC_i18n::t('Integrations'), THWEC_i18n::t('Integrations').'<span class="thwec-integration-submenu">New</span>', $manage_cap, 'th_email_customizer_integrations', array($this, 'output_settings'));	
		$this->screen_id .= add_submenu_page('th_email_customizer_templates', THWEC_i18n::t('Plugin License'), THWEC_i18n::t('Plugin License') . ' <span class="th-license-warning-icon"></span>', $manage_cap, 'th_email_customizer_license_settings', array($this, 'output_settings'));
	}
	
	/**
	 * Add screen ids
	 *
	 * @param  array $ids screen ids
	 * @return array $links screen ids
	 */	
	public function add_screen_id($ids){
		$ids[] = 'woocommerce_page_th_email_customizer_pro';
		$ids[] = strtolower( THWEC_i18n::t('WooCommerce') ) .'_page_th_email_customizer_pro';

		return $ids;
	}
	
	/**
	 * Add to plugin action links
	 *
	 * @param  array $links links to display
	 * @return array $links links to display
	 */	
	public function plugin_action_links($links) {
		$settings_link = '<a href="'.admin_url('admin.php?page=th_email_customizer_templates').'">'. __('Settings') .'</a>';
		array_unshift($links, $settings_link);
		return $links;
	}
	
	/**
	 * Add to plugin meta in plugin listings page
	 *
	 * @param  array $links links to display
	 * @param  string $file file path
	 * @return array $links links to display
	 */	
	public function plugin_row_meta( $links, $file ) {
		if(THWEC_BASE_NAME == $file) {
			$doc_link = esc_url('https://www.themehigh.com/help-guides/woocommerce-email-customizer/');
			$support_link = esc_url('https://www.themehigh.com/help-guides/');
				
			$row_meta = array(
				'docs' => '<a href="'.$doc_link.'" target="_blank" aria-label="'.THWEC_i18n::esc_attr__t('View plugin documentation').'">'.THWEC_i18n::esc_html__t('Docs').'</a>',
				'support' => '<a href="'.$support_link.'" target="_blank" aria-label="'. THWEC_i18n::esc_attr__t('Visit premium customer support' ) .'">'. THWEC_i18n::esc_html__t('Premium support') .'</a>',
			);

			return array_merge( $links, $row_meta );
		}
		return (array) $links;
	}

	/**
	 * Add custom class to body classes
	 *
	 * @param  string $classes classes
	 * @return string $classes classes
	 */	
	public function add_thwec_body_class( $classes ){
		$pages = array('th_email_customizer_templates', 'th_email_customizer_mapping', 'th_email_customizer_pro');
		$page = isset( $_GET['page'] ) ? sanitize_text_field( $_GET['page'] ) : false;
		if( $page && in_array( $page, $pages ) ){
			$page = str_replace('th_email_customizer_', "", $_GET['page'] );
			$page = $page == 'pro' ? 'builder' : $page;
			$classes .= ' thwec-page thwec-'.$page.'-page';
			$action = isset( $_GET['action'] ) ? sanitize_key( $_GET['action'] ) : false;
			if( $action && THWEC_Utils::is_migrate_action( sanitize_key( $action ) ) ){
				$classes .= ' thwec-migrate-page-'.$action;
			}
		}
		return $classes;
	}

	/**
	 * Disable admin notices in selected plugin pages
	 */	
	public function disable_admin_notices(){
		$page  = isset( $_GET['page'] ) ? esc_attr( $_GET['page'] ) : '';
		$action = isset( $_GET['action'] ) ? esc_attr( $_GET['action'] ) : '';
		$pages = array('th_email_customizer_pro');
		if(in_array($page, $pages) || THWEC_Utils::is_migrate_action( $action ) ){
			global $wp_filter;
      		if (is_user_admin() ) {
        		if (isset($wp_filter['user_admin_notices'])){
            		unset($wp_filter['user_admin_notices']);
        		}
      		} elseif(isset($wp_filter['admin_notices'])){
            	unset($wp_filter['admin_notices']);
      		}
      		if(isset($wp_filter['all_admin_notices'])){
        		unset($wp_filter['all_admin_notices']);
      		}
		}
	}

	/**
	 * Upgrade database if required
	 */	
	public function display_thwec_admin_notices() {
		if( $this->database_update_required() && apply_filters('thwec_database_upgrade', false ) ){
	 		$premium_settings = THWEC_Utils::get_template_settings();
			if( $premium_settings && is_array( $premium_settings ) ){
				if( !isset( $premium_settings[THWEC_Utils::get_template_samples_key()] ) || apply_filters('thwec_reset_sample_templates', false ) ){
					$premium_settings['thwec_samples'] = THWEC_Utils::get_sample_settings();
				}else if( ( isset( $premium_settings[THWEC_Utils::get_template_samples_key()] ) && empty( $premium_settings[THWEC_Utils::get_template_samples_key()] ) ) || apply_filters('thwec_reset_sample_templates', false ) ){
					$premium_settings['thwec_samples'] = THWEC_Utils::get_sample_settings();
				}
				$save = THWEC_Utils::save_template_settings( $premium_settings );
				if( $save ){
					update_option('thwec_version', THWEC_VERSION);
					?>
    				<div class="notice notice-success is-dismissible">
        		    	<p><?php _e( 'Email Customizer database upgrade successful!', 'thwec' ); ?></p>
        			</div>
    				<?php
				}
			}
    	}
	}

	/**
	 * Checks whether database update is required
	 *
	 * @return boolean update required or not
	 */	
	public function database_update_required(){
		// Version before 2.0.6 doesn't have a version option.
		// So older version updated to 2.0.6 or higher requires db upgrade
		$pre_version = get_option('thwec_version');
		if( !$pre_version || $pre_version < '3.0.0' ){ // 
			return true;
		}
		return apply_filters('thwec_force_update_db', false);
	}

	/**
	 * Render admin plugin pages
	 */
	public function output_settings(){
		$page  = isset( $_GET['page'] ) ? esc_attr( $_GET['page'] ) : 'th_email_customizer_pro';

		if($page === 'th_email_customizer_pro'){
			$template_settings = THWEC_Admin_Settings_Customizer::instance();	
			$template_settings->render_page();	

		}else if($page === 'th_email_customizer_advanced_settings'){
			$advanced_settings = THWEC_Admin_Settings_Advanced::instance();	
			$advanced_settings->render_page();

		}else if($page === 'th_email_customizer_mapping'){
			$advanced_settings = THWEC_Admin_Template_Mapping::instance();	
			$advanced_settings->render_page();

		}else if($page === 'th_email_customizer_license_settings'){
			$license_settings = THWEC_Admin_Settings_License::instance();	
			$license_settings->render_page();	

		}else if($page === 'th_email_customizer_integrations'){	
			$license_settings = THWEC_Admin_Settings_Integrations::instance();		
			$license_settings->render_page();		
		
		}else{
			$template_settings = THWEC_Admin_Settings_Templates::instance();	
			$template_settings->render_page( $this->migrate_instance );	
		}
	}

	private function get_template_details(){
		$importer = THWEC_Builder_Importer::instance();
		return $importer->prepare_template_data( $_POST );
	}

	private function get_woo_email_instances(){	
		$woo_emails = array();
		$emails = apply_filters('thwec_woo_email_instances', array());
		if(is_array($emails) && !empty($emails)){
			foreach ($emails as $key => $email) {
				$woo_emails[$key] = $email;
				if( $key == 'WC_Email_Customer_Refunded_Order' ){
					$woo_emails["WC_Email_Customer_Partial_Refunded_Order"] = "Refunded order (Partial)";
				}
			}
		}
		return $woo_emails;
	}

	private function get_woo_orders(){
		$woo_orders = [];
		$orders = THWEC_Utils::get_woo_orders();
		foreach ($orders as $key => $order) {
			if(!$order){
            	continue;
            }
	    	$buyer = $this->get_buyer_info( $order );
	    	$order_id = $order->get_id();
	    	if( $buyer ){
				$user_string = sprintf( '(#%1$s) %2$s', $order_id, $buyer );
				$woo_orders[$order_id] = wp_kses_post( $user_string );
			}
		}
		return $woo_orders;
	}

	private function get_buyer_info( $order ){
		$buyer = false;
		if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
			$buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
		} elseif ( $order->get_billing_company() ) {
			$buyer = trim( $order->get_billing_company() );
		} elseif ( $order->get_customer_id() ) {
			$user  = get_user_by( 'id', $order->get_customer_id() );
			$buyer = ucwords( $user->display_name );
		}
		return $buyer;
	}

	public function submenu_icon_css(){
		?>
		<style>
			ul#adminmenu .thwec-integration-submenu {
				margin-left: 5px;
			    width: 28px;
			    height: 14px;
			    background-color: #E48D3D;
			    border-radius: 8px;
			    padding: 1px 8px;
			    line-height: 1.6;
			    border-radius: 9px;
			    font-size: 9px;
			    text-transform: uppercase;
			    color: #fff;
			    vertical-align: middle;
			}
		</style>
		<?php
	}

	public function new_features_popup(){
		if( ( isset($_GET['thwec_dissmis_popup']) ) ) {
			$this->thwec_popup_actions();
		}
		$pages = array('th_email_customizer_templates', 'th_email_customizer_mapping', 'th_email_customizer_pro', 'th_email_customizer_integrations');
		$popup_version = get_option('thwec_feature_popup_since', false);
		$show_popup = version_compare( THWEC_VERSION, $popup_version, '>' ) ? true : false;
		$page = isset( $_GET['page'] ) ? sanitize_text_field( $_GET['page'] ) : false;
		if( $show_popup && $page && in_array( $page, $pages ) ){
			$feature_popup = new THWEC_Admin_Settings_Popup();
			$feature_popup->render_popup();
		}
	}

	public function thwec_popup_actions(){
		$nonce = isset($_GET['thwec_feature_popup_nonce']) ? $_GET['thwec_feature_popup_nonce'] : false;
		if(!wp_verify_nonce($nonce, 'thwec_feature_popup_security')){
			die();
		}
		update_option('thwec_feature_popup_since', THWEC_VERSION);
	}

	public function quick_links(){
		$current_screen = get_current_screen();
		$pages = array(
			'toplevel_page_th_email_customizer_templates',
			'email-customizer_page_th_email_customizer_mapping',
			'email-customizer_page_th_email_customizer_integrations',
			'email-customizer_page_th_email_customizer_license_settings',
			'email-customizer_page_th_email_customizer_pro'
		);

		if( isset($current_screen->id ) && !in_array($current_screen->id, $pages) ){
			return;
		}
		?>
		<div class="th_quick_widget-float">
			<div id="myDIV" class="th_quick_widget">
				<div class="th_whead">
					<div class="th_whead_close_btn" onclick="thwecWidgetClose()">
						<svg
						width="8"
                		height="8"
                		viewBox="0 0 8 8"
                		fill="none"
                		xmlns="http://www.w3.org/2000/svg"
                		>
                		<path
                		d="M1 1.25786C1.00401 1.25176 1.00744 1.24529 1.01024 1.23853C1.08211 0.993028 1.35531 0.919956 1.53673 1.10012C1.86493 1.42605 2.19216 1.75313 2.51843 2.08137L3.95107 3.51439C3.96595 3.52947 3.9816 3.54378 4.01406 3.57471C4.02464 3.55274 4.0376 3.53199 4.0527 3.51285C4.84988 2.71382 5.64738 1.91551 6.4452 1.11791C6.53582 1.02724 6.63706 0.978916 6.76632 1.01139C6.81535 1.02341 6.86066 1.04735 6.89822 1.08109C6.93579 1.11484 6.96444 1.15734 6.98165 1.20483C6.99885 1.25231 7.00407 1.30332 6.99684 1.35331C6.98961 1.4033 6.97016 1.45073 6.9402 1.49139C6.92103 1.51599 6.90004 1.53912 6.87741 1.56059C6.08049 2.35691 5.28376 3.15329 4.48723 3.94973C4.46465 3.96936 4.44437 3.99147 4.42675 4.01565C4.4484 4.02488 4.46879 4.03683 4.48742 4.05122C5.28717 4.85024 6.08661 5.64927 6.88572 6.44829C6.95508 6.51749 7.0001 6.59501 6.99836 6.69592C6.9976 6.7567 6.97884 6.81588 6.94444 6.86599C6.91005 6.91609 6.86158 6.95486 6.80515 6.97738C6.78757 6.98434 6.77037 6.99227 6.75279 6.99961H6.63571C6.54702 6.97371 6.48114 6.91688 6.41584 6.85231C5.62845 6.06424 4.8408 5.27604 4.05289 4.48772C4.0382 4.46942 4.02575 4.44943 4.0158 4.42818L3.98759 4.43282C3.97559 4.45322 3.96196 4.47262 3.94682 4.49081C3.16072 5.27708 2.37481 6.06366 1.58909 6.85057C1.5234 6.91649 1.45578 6.97564 1.36381 7H1.24653C1.18653 6.98245 1.1322 6.94939 1.08903 6.90415C1.04585 6.85891 1.01534 6.8031 1.00058 6.74231V6.63677C1.02879 6.54011 1.09409 6.46975 1.16365 6.40035C1.94576 5.61975 2.72722 4.83871 3.50804 4.05721C3.52747 4.04089 3.54836 4.02639 3.57045 4.01391V3.98549C3.54826 3.97322 3.5273 3.95885 3.50785 3.94258C2.72613 3.16121 1.94486 2.38023 1.16403 1.59964C1.09448 1.53024 1.02879 1.46046 1.00058 1.36341L1 1.25786Z"
                		fill="white"
                  		stroke="white"
                  		stroke-width="0.5"
                  		/>
                  		</svg>
            		</div>
            		<!-- -----------------------------Widget head icon ----------------------------->
            		<div class="th_whead_icon">
            			<svg width="16" height="13" viewBox="0 0 16 13" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M9.89459 0H0.508202C0.441464 0 0.37538 0.013146 0.313722 0.0386855C0.252064 0.0642251 0.196039 0.101657 0.148848 0.148848C0.101657 0.196039 0.064224 0.252065 0.0386845 0.313723C0.0131449 0.375381 0 0.441464 0 0.508202V2.5017C-6.61617e-08 2.56841 0.0131492 2.63446 0.0386975 2.69607C0.0642459 2.75769 0.101692 2.81367 0.148892 2.8608C0.196092 2.90794 0.252121 2.9453 0.313775 2.97076C0.375429 2.99623 0.441497 3.00928 0.508202 3.00919H9.89459C10.0292 3.00919 10.1583 2.95572 10.2534 2.86055C10.3486 2.76538 10.4021 2.6363 10.4021 2.5017V0.508202C10.4022 0.441497 10.3891 0.375429 10.3636 0.313775C10.3382 0.252121 10.3008 0.196092 10.2537 0.148892C10.2066 0.101692 10.1506 0.064247 10.089 0.0386986C10.0273 0.0131503 9.96129 -6.61617e-08 9.89459 0Z" fill="#845DE2"/>
							<path d="M15.2318 4.67675H3.88198C3.74732 4.67675 3.61817 4.7302 3.52288 4.82535C3.42759 4.9205 3.37397 5.04958 3.37378 5.18424V7.18131C3.37397 7.31597 3.42759 7.44505 3.52288 7.54021C3.61817 7.63536 3.74732 7.6888 3.88198 7.6888H15.2318C15.2985 7.6888 15.3645 7.67567 15.4261 7.65017C15.4876 7.62467 15.5436 7.58729 15.5907 7.54016C15.6378 7.49304 15.6752 7.43709 15.7007 7.37552C15.7262 7.31395 15.7393 7.24796 15.7393 7.18131V5.18424C15.7393 5.04965 15.6859 4.92057 15.5907 4.82539C15.4955 4.73022 15.3664 4.67675 15.2318 4.67675Z" fill="#6E55FF"/>
							<path d="M15.2318 9.35279H12.595C12.4604 9.35298 12.3313 9.4066 12.2361 9.50189C12.141 9.59718 12.0875 9.72634 12.0875 9.861V11.8574C12.0874 11.9241 12.1005 11.9901 12.126 12.0518C12.1514 12.1134 12.1888 12.1695 12.2359 12.2167C12.283 12.2639 12.339 12.3013 12.4006 12.3269C12.4623 12.3524 12.5283 12.3656 12.595 12.3656H15.2318C15.3666 12.3656 15.4959 12.312 15.5912 12.2167C15.6865 12.1214 15.74 11.9921 15.74 11.8574V9.86385C15.7404 9.79687 15.7275 9.73048 15.7021 9.66849C15.6768 9.60651 15.6394 9.55014 15.5922 9.50265C15.5449 9.45516 15.4888 9.41747 15.427 9.39175C15.3651 9.36603 15.2988 9.35279 15.2318 9.35279Z" fill="#6E55FF"/>
							<path d="M9.89463 9.35279H7.2557C7.12085 9.35355 6.99181 9.4078 6.89693 9.50362C6.80204 9.59944 6.74907 9.729 6.74964 9.86385V11.8602C6.74964 11.995 6.80318 12.1243 6.89849 12.2196C6.99379 12.3149 7.12306 12.3684 7.25784 12.3684H9.89463C9.96134 12.3684 10.0274 12.3553 10.089 12.3297C10.1506 12.3042 10.2066 12.2667 10.2537 12.2195C10.3009 12.1723 10.3382 12.1163 10.3637 12.0546C10.3892 11.993 10.4022 11.9269 10.4021 11.8602V9.86385C10.4025 9.79693 10.3897 9.7306 10.3643 9.66866C10.339 9.60672 10.3017 9.55039 10.2545 9.5029C10.2074 9.45542 10.1513 9.41771 10.0896 9.39195C10.0278 9.36619 9.96155 9.35288 9.89463 9.35279Z" fill="#6E55FF"/>
							<path d="M15.2318 0H12.595C12.5283 -6.61617e-08 12.4623 0.0131503 12.4006 0.0386986C12.339 0.064247 12.283 0.101692 12.2359 0.148892C12.1888 0.196092 12.1514 0.252121 12.126 0.313775C12.1005 0.375429 12.0874 0.441497 12.0875 0.508202V2.5017C12.0875 2.56835 12.1007 2.63434 12.1262 2.69591C12.1517 2.75748 12.189 2.81342 12.2362 2.86055C12.2833 2.90767 12.3392 2.94506 12.4008 2.97056C12.4624 2.99606 12.5284 3.00919 12.595 3.00919H15.2318C15.2985 3.00928 15.3646 2.99623 15.4262 2.97076C15.4879 2.9453 15.5439 2.90794 15.5911 2.8608C15.6383 2.81367 15.6758 2.75769 15.7013 2.69607C15.7269 2.63446 15.74 2.56841 15.74 2.5017V0.508202C15.74 0.373418 15.6865 0.244155 15.5912 0.148848C15.4959 0.0535418 15.3666 0 15.2318 0Z" fill="#6E55FF"/>
						</svg>
            		</div>
            		<!--------------------------Whidget heading section ---------------------------->
            		<div class="th_quick_widget_heading">
						<div class="th_whead_t1"><p>Welcome, we're</p><p><b style="font-size: 28px;">ThemeHigh</b></p></div>
                		</div>
        			</div>
        			<!-- --------------------Widget Body--------------------------------------- -->
        			<div class="th_quick_widget_body">
        				<ul>
        					<li>
        						<div class="list_icon" style="background-color: rgba(199, 0, 255, 0.15);">
        							<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
									<path d="M6.91072 14.9998C6.70136 14.914 6.47074 14.8589 6.28742 14.736C5.91747 14.4906 5.75542 14.1145 5.74075 13.6743C5.73818 13.5961 5.74075 13.518 5.74075 13.4398C5.74075 13.1529 5.77045 12.8748 5.52773 12.6327C5.33157 12.4364 5.30041 12.1458 5.30041 11.8652C5.30041 11.233 5.08922 10.6945 4.64448 10.2289C2.62793 8.12188 3.48405 4.66072 6.25222 3.74646C7.04263 3.48069 7.89711 3.47384 8.69167 3.7269C9.48624 3.97997 10.1796 4.47977 10.671 5.15381C11.6654 6.51127 11.7123 8.25396 10.8005 9.66829C10.6527 9.88635 10.4864 10.0913 10.3037 10.281C9.88934 10.7304 9.69465 11.2602 9.69465 11.8652C9.69465 12.1513 9.62976 12.4155 9.46733 12.6525C9.45927 12.6646 9.4556 12.6822 9.4446 12.6892C9.22792 12.8429 9.25651 13.0696 9.25138 13.2938C9.24551 13.5459 9.25358 13.8074 9.18832 14.047C9.04459 14.5742 8.67501 14.8798 8.13641 14.9789C8.11799 14.9841 8.10017 14.9912 8.08325 15.0002L6.91072 14.9998ZM7.49002 12.363C7.76317 12.363 8.03632 12.363 8.30947 12.363C8.64238 12.363 8.79087 12.1913 8.81947 11.8575C8.84457 11.5134 8.89829 11.172 8.98006 10.8368C9.11536 10.3133 9.46074 9.913 9.81051 9.51236C10.5071 8.71403 10.74 7.77225 10.4705 6.75452C10.1368 5.49501 9.29721 4.72126 8.01139 4.47802C6.38788 4.1713 4.80874 5.24517 4.49159 6.85614C4.3211 7.72565 4.47179 8.53609 4.98693 9.26288C5.15522 9.50062 5.37081 9.70314 5.55046 9.93464C5.99484 10.5029 6.17376 11.16 6.17779 11.8732C6.17779 12.1888 6.35378 12.3608 6.66873 12.3627C6.94335 12.3645 7.21686 12.363 7.49002 12.363ZM6.6218 13.2487C6.6218 13.4174 6.61043 13.5789 6.62473 13.7363C6.6345 13.8397 6.68214 13.9358 6.75849 14.0062C6.83485 14.0766 6.93451 14.1162 7.03831 14.1175C7.34482 14.1255 7.65146 14.1255 7.95822 14.1175C8.06198 14.1153 8.16127 14.0748 8.23696 14.0037C8.31264 13.9327 8.35937 13.8361 8.36813 13.7326C8.3817 13.5745 8.3707 13.4145 8.3707 13.2487H6.6218Z" fill="#C700FF"/>
									<path d="M0 7.38305C0.11696 7.1299 0.317515 7.04992 0.589199 7.05653C1.13 7.07047 1.6708 7.05653 2.21161 7.0624C2.53719 7.0657 2.74764 7.36691 2.63288 7.65674C2.56322 7.83138 2.42793 7.93447 2.24094 7.93631C1.63671 7.94181 1.03101 7.94034 0.428609 7.93631C0.210455 7.93631 0.0923946 7.78955 0 7.61602V7.38305Z" fill="#C700FF"/>
									<path d="M7.93549 1.341C7.93549 1.62423 7.93732 1.90747 7.93549 2.1907C7.93292 2.46659 7.75217 2.66104 7.50358 2.66508C7.24693 2.66911 7.05921 2.47136 7.05811 2.18813C7.05615 1.61677 7.05615 1.04566 7.05811 0.474795C7.05811 0.1989 7.24143 0.004086 7.49002 5.02997e-05C7.74667 -0.00361851 7.93292 0.193764 7.93549 0.476996C7.93732 0.764998 7.93549 1.053 7.93549 1.341Z" fill="#C700FF"/>
									<path d="M13.6692 7.06071C13.9523 7.06071 14.235 7.05851 14.518 7.06071C14.7934 7.06328 14.9877 7.24415 14.991 7.49437C14.9939 7.75118 14.7967 7.93719 14.5143 7.93829C13.9436 7.94049 13.3727 7.94049 12.8017 7.93829C12.5268 7.93829 12.3321 7.75485 12.3291 7.50464C12.3262 7.25443 12.5231 7.06438 12.8058 7.06071C13.0885 7.05704 13.3814 7.06071 13.6692 7.06071Z" fill="#C700FF"/>
									<path d="M4.21244 3.71903C4.19521 3.95346 4.11602 4.09214 3.94919 4.16809C3.78237 4.24403 3.61921 4.22349 3.48575 4.10095C3.32333 3.9542 3.17117 3.7946 3.01571 3.63941C2.7499 3.37416 2.48261 3.10964 2.21973 2.84108C2.15821 2.78388 2.1153 2.7095 2.09653 2.6276C2.07777 2.5457 2.08403 2.46004 2.1145 2.38174C2.1739 2.21591 2.29782 2.10034 2.47125 2.10108C2.59224 2.10108 2.7444 2.1407 2.82799 2.22031C3.25697 2.62608 3.67127 3.0469 4.08155 3.47138C4.15451 3.54696 4.18421 3.66326 4.21244 3.71903Z" fill="#C700FF"/>
									<path d="M11.2831 4.21644C11.0558 4.20397 10.9164 4.13243 10.8365 3.97504C10.7566 3.81764 10.7632 3.64998 10.8791 3.50873C10.9714 3.39573 11.08 3.29594 11.183 3.19211C11.5008 2.87415 11.8185 2.55619 12.1363 2.23822C12.2672 2.10835 12.4234 2.05478 12.6041 2.11495C12.6816 2.13889 12.7505 2.18474 12.8025 2.24697C12.8546 2.30919 12.8875 2.38515 12.8974 2.46569C12.9094 2.53348 12.9044 2.60319 12.8828 2.66856C12.8613 2.73394 12.8238 2.79294 12.7739 2.84027C12.3614 3.25595 11.9497 3.67199 11.5291 4.0796C11.4536 4.15224 11.3377 4.18489 11.2831 4.21644Z" fill="#C700FF"/>
									<path d="M5.36065 6.98437C5.42475 6.66988 5.56528 6.37604 5.76982 6.1288C6.1966 5.60159 6.75463 5.3312 7.43109 5.30515C7.71488 5.29451 7.92093 5.46695 7.93303 5.72193C7.94513 5.97691 7.75264 6.16806 7.47142 6.18237C6.84813 6.21355 6.43382 6.52613 6.23033 7.11645C6.14343 7.36776 5.94508 7.50021 5.72216 7.45508C5.61453 7.43496 5.51812 7.3758 5.45141 7.28893C5.38469 7.20207 5.35237 7.09361 5.36065 6.98437Z" fill="#C700FF"/>
									</svg>

                    			</div>
                    			<a href="https://app.loopedin.io/email-customizer-for-woocommerce" target="_blank" class="quick-widget-doc-link">Request a feature</a></li>
               			 	<li>
               			 		<div class="list_icon" style="background-color: #E4EFFF;">
        							<svg width="12" height="14" viewBox="0 0 12 14" fill="none" xmlns="http://www.w3.org/2000/svg">
									<path d="M0.000760092 6.99536C0.000760092 5.6649 0.000760092 4.33443 0.000760092 3.00397C0.000760092 1.27356 1.27135 0.00458886 3.00162 0.00361535C4.08833 0.00361535 5.17455 0.00750876 6.26078 0.000694197C6.38439 -0.00426304 6.50763 0.0173748 6.62218 0.0641462C6.73672 0.110918 6.83991 0.181735 6.92477 0.271817C8.40906 1.7668 9.89806 3.25708 11.3918 4.74266C11.4794 4.82578 11.5484 4.92663 11.5941 5.03851C11.6399 5.15038 11.6612 5.27072 11.6569 5.3915C11.653 7.27427 11.6569 9.15703 11.6569 11.0379C11.6569 12.7094 10.3741 13.9949 8.7066 13.9978C6.78905 14.0007 4.87133 14.0007 2.95346 13.9978C1.28642 13.9949 0.00611083 12.7089 0.00367862 11.0379C0.000111385 9.69149 -0.000861379 8.34399 0.000760092 6.99536ZM10.4894 5.8364C9.88963 5.8364 9.32195 5.83932 8.74892 5.8364C7.11691 5.82715 5.83465 4.53871 5.83027 2.90273C5.83027 2.39261 5.83027 1.88054 5.83027 1.37237V1.17134C4.85204 1.17134 3.90007 1.16842 2.94811 1.17134C1.92658 1.17572 1.17065 1.93798 1.16968 2.96357C1.16676 5.65403 1.16676 8.34432 1.16968 11.0344C1.16968 12.0703 1.92804 12.832 2.96027 12.8354C4.87166 12.839 6.78289 12.839 8.69395 12.8354C8.86344 12.8365 9.03234 12.8155 9.19645 12.7731C9.97475 12.5633 10.4894 11.8882 10.4914 11.0641C10.4952 9.37607 10.4914 7.68752 10.4914 6.00189L10.4894 5.8364ZM9.64787 4.68863C8.75427 3.76964 7.89668 2.89007 7.04346 2.01148L6.99481 2.04604C6.99481 2.35951 6.988 2.67346 6.99481 2.98645C7.0167 3.77596 7.59606 4.49052 8.37242 4.62292C8.78006 4.69057 9.20131 4.66818 9.64787 4.68863Z" fill="#0060FE"/>
									<path d="M5.83661 7.58628C6.58929 7.58628 7.34182 7.58628 8.09418 7.58628C8.47799 7.58628 8.74309 7.82966 8.74066 8.17379C8.73823 8.51793 8.47555 8.75206 8.10342 8.75206C6.58605 8.75206 5.06884 8.75206 3.55179 8.75206C3.18015 8.75206 2.91942 8.50868 2.91504 8.1733C2.91504 7.82771 3.17577 7.5892 3.56103 7.58628C4.31923 7.58531 5.07776 7.58531 5.83661 7.58628Z" fill="#0060FE"/>
									<path d="M5.83607 11.0851C5.06506 11.0851 4.29454 11.0885 3.52353 11.0851C3.05849 11.0826 2.77393 10.6319 2.98261 10.2352C3.02899 10.1384 3.10253 10.0571 3.19426 10.0014C3.28599 9.94562 3.39194 9.91778 3.49921 9.92124C5.05258 9.9193 6.60611 9.9193 8.1598 9.92124C8.23598 9.9208 8.31149 9.93542 8.382 9.96428C8.45251 9.99314 8.51661 10.0357 8.57064 10.0894C8.62466 10.1431 8.66754 10.207 8.69679 10.2774C8.72605 10.3478 8.7411 10.4233 8.7411 10.4995C8.74151 10.5771 8.72638 10.654 8.69661 10.7257C8.66683 10.7973 8.62303 10.8623 8.56776 10.9167C8.51249 10.9712 8.44688 11.014 8.37481 11.0427C8.30274 11.0713 8.22567 11.0852 8.14813 11.0836C7.37712 11.088 6.6066 11.0851 5.83607 11.0851Z" fill="#0060FE"/>
									<path d="M4.0796 6.41952C3.88502 6.41952 3.69045 6.42342 3.49587 6.41952C3.34231 6.41953 3.19493 6.359 3.08567 6.25103C2.97641 6.14306 2.91406 5.99636 2.91214 5.84272C2.91134 5.76494 2.92618 5.68779 2.9558 5.61587C2.98541 5.54395 3.02918 5.47873 3.08451 5.42409C3.13984 5.36945 3.20559 5.32651 3.27785 5.29783C3.35011 5.26916 3.4274 5.25532 3.50511 5.25715C3.88746 5.25229 4.2698 5.25229 4.65214 5.25715C4.72974 5.25566 4.80684 5.26967 4.87896 5.29836C4.95108 5.32705 5.01676 5.36984 5.07215 5.42422C5.12755 5.47861 5.17155 5.54351 5.20158 5.61511C5.23161 5.68672 5.24707 5.7636 5.24706 5.84126C5.24463 6.16544 4.98924 6.41417 4.64728 6.42001C4.45659 6.42244 4.26834 6.41952 4.0796 6.41952Z" fill="#0060FE"/>
									</svg>
                    			</div>
                    			<a href="https://www.themehigh.com/docs/category/email-customizer-for-woocommerce/" target="_blank" class="quick-widget-doc-link">Documentation</a></li>
               			 	<li>

               			 	<div class="list_icon" style="background-color: rgba(5, 15, 250, 0.15);">
               			 		<svg width="14" height="13" viewBox="0 0 14 13" fill="none" xmlns="http://www.w3.org/2000/svg">
               			 			<path
				                    d="M0 3.38284C0.0365282 3.2037 0.0639243 3.02455 0.109585 2.84791C0.474866 1.41869 1.66897 0.371758 3.16005 0.190821C4.2822 0.0543117 5.26626 0.369967 6.10166 1.11593C6.34019 1.33091 6.56776 1.5552 6.82858 1.80206C6.87606 1.74509 6.91698 1.68705 6.96738 1.63724C7.33267 1.27609 7.69283 0.909913 8.13081 0.626504C9.82352 -0.468078 11.8512 -0.070732 13.0939 1.36996C13.7076 2.08117 14.0261 2.90596 13.9983 3.84576C13.9735 4.68452 13.652 5.41507 13.1315 6.06716C13.0336 6.19006 12.927 6.3065 12.7827 6.4749C12.8287 6.50034 12.8923 6.51897 12.931 6.55946C13.3072 6.94104 13.438 7.39428 13.2802 7.90198C13.1249 8.40359 12.7724 8.73142 12.2468 8.82673C12.0393 8.86435 11.9816 8.93135 11.9458 9.12626C11.8362 9.7307 11.312 10.156 10.6812 10.195C10.6633 10.195 10.6447 10.1993 10.6147 10.2029C10.5442 10.812 10.2418 11.2645 9.62846 11.4491C9.01515 11.6336 8.50376 11.4197 8.08149 10.9374C7.92625 11.0922 7.77794 11.2405 7.62891 11.3882C7.50362 11.5121 7.37942 11.6368 7.25157 11.7579C7.08572 11.9155 6.88143 12.0286 6.65823 12.0866C6.43504 12.1445 6.20042 12.1453 5.97682 12.0889C5.75323 12.0324 5.54814 11.9206 5.3812 11.7642C5.21426 11.6078 5.09104 11.4119 5.02335 11.1954C4.99298 11.08 4.9686 10.9632 4.9503 10.8453C4.09554 10.6694 3.72295 10.3079 3.6309 9.56123C3.15238 9.52934 2.77066 9.32332 2.53505 8.90233C2.29945 8.48133 2.32757 8.05425 2.57158 7.62072C2.50948 7.56483 2.44264 7.50535 2.37725 7.4448C1.96595 7.06465 1.55318 6.68629 1.14479 6.30328C0.509202 5.70816 0.131502 4.98405 0.0277618 4.12558C0.0218314 4.10007 0.0132612 4.07522 0.00218937 4.05141L0 3.38284ZM9.90169 6.39249C10.0843 5.91668 10.4032 5.59064 10.9059 5.47992C11.4085 5.36921 11.8508 5.49856 12.2209 5.85828C12.2574 5.8246 12.2881 5.7988 12.3155 5.77014C13.0245 5.02669 13.2853 4.15209 13.0968 3.15461C12.8079 1.62542 11.2087 0.582434 9.65695 0.868709C8.6769 1.04786 8.0435 1.69099 7.40901 2.36207C7.85064 2.78306 8.29043 3.19796 8.72402 3.61788C8.9613 3.85006 9.11138 4.15423 9.14979 4.4808C9.1882 4.80738 9.11267 5.13708 8.93552 5.41615C8.58193 5.97652 7.86342 6.22481 7.2187 6.01306C6.99754 5.94105 6.79715 5.81821 6.63425 5.65477C6.48193 5.50393 6.32777 5.35452 6.17837 5.20834C6.16397 5.21522 6.15016 5.22325 6.1371 5.23234C5.19906 6.15148 4.26247 7.07193 3.32735 7.9937C3.25608 8.07398 3.21248 8.1743 3.20279 8.28033C3.1827 8.47166 3.28607 8.61319 3.46068 8.69882C3.54384 8.7429 3.6395 8.75882 3.73283 8.74412C3.82616 8.72941 3.91193 8.6849 3.97682 8.61749C4.24129 8.36668 4.49954 8.1062 4.76145 7.8511C4.95578 7.66192 5.20818 7.64974 5.3795 7.81885C5.55082 7.98797 5.53548 8.23483 5.34297 8.42544C5.10846 8.65654 4.8714 8.88585 4.63762 9.11766C4.40384 9.34948 4.39617 9.65761 4.61095 9.87007C4.81916 10.0768 5.1512 10.0671 5.37804 9.84535C5.61438 9.61569 5.84816 9.38351 6.0845 9.15385C6.277 8.96682 6.53343 8.95679 6.70256 9.12698C6.87168 9.29716 6.8567 9.53794 6.66931 9.72353C6.43188 9.95857 6.19152 10.1893 5.95482 10.4258C5.73565 10.6443 5.72835 10.9632 5.93546 11.17C6.14258 11.3767 6.46877 11.3738 6.69269 11.1574C6.94839 10.9095 7.20043 10.6558 7.45978 10.41C7.51786 10.3545 7.52444 10.3111 7.49156 10.237C7.3469 9.91676 7.33535 9.55381 7.45938 9.22538C7.58341 8.89695 7.83322 8.62897 8.15564 8.47847C8.18998 8.46235 8.22286 8.44264 8.25683 8.42544C7.93319 7.89732 7.92807 7.32692 8.25683 6.88909C8.67361 6.34018 9.23067 6.19221 9.90169 6.395V6.39249ZM3.1396 7.04673C3.17941 6.99944 3.20827 6.95824 3.24333 6.92384C4.0097 6.17119 4.77679 5.41878 5.54461 4.6666C5.9077 4.31189 6.42421 4.31153 6.7884 4.66194C6.93451 4.80275 7.07733 4.94858 7.22417 5.0876C7.37102 5.22661 7.54964 5.30257 7.75749 5.27498C8.02341 5.24094 8.21628 5.10157 8.30541 4.85076C8.39491 4.59387 8.32514 4.36492 8.12898 4.17753C7.27093 3.35704 6.41946 2.52939 5.54899 1.72216C4.85898 1.08153 4.02613 0.840046 3.0932 1.02206C2.03389 1.22915 1.30332 1.85294 0.968724 2.85651C0.628646 3.87191 0.844163 4.80705 1.5897 5.58741C2.07151 6.09224 2.60665 6.54799 3.1396 7.04673ZM10.6184 9.39319C10.7214 9.39015 10.8214 9.35814 10.9064 9.30098C10.9914 9.24381 11.0579 9.16389 11.098 9.07072C11.1941 8.86614 11.171 8.66048 11.0107 8.49746C10.5924 8.07467 10.1705 7.65691 9.73622 7.24845C9.51705 7.03993 9.19305 7.06931 8.97936 7.29037C8.88103 7.38892 8.82655 7.52168 8.82785 7.65957C8.82915 7.79745 8.88613 7.9292 8.9863 8.02595C9.39176 8.42974 9.80233 8.82852 10.2115 9.22909C10.2646 9.28212 10.3281 9.32401 10.3983 9.35222C10.4684 9.38043 10.5437 9.39437 10.6195 9.39319H10.6184ZM11.9381 8.08829C12.1938 8.05246 12.3662 7.94246 12.4641 7.73537C12.562 7.52828 12.5277 7.32154 12.3637 7.15422C12.1116 6.89649 11.8545 6.64366 11.5922 6.39572C11.4914 6.29957 11.356 6.24643 11.2154 6.24791C11.0748 6.24939 10.9406 6.30536 10.8419 6.4036C10.6228 6.61177 10.6071 6.93423 10.816 7.14849C11.0717 7.40969 11.3299 7.66765 11.6006 7.91237C11.6927 7.99406 11.8256 8.03096 11.9392 8.08829H11.9381ZM8.16624 9.7049C8.21628 9.81561 8.24368 9.94567 8.32112 10.0338C8.49452 10.229 8.68098 10.4126 8.87927 10.5834C9.09844 10.7726 9.41477 10.7443 9.61787 10.5372C9.71522 10.441 9.7707 10.3115 9.77261 10.1759C9.77452 10.0404 9.72271 9.90941 9.6281 9.8106C9.46031 9.63456 9.28656 9.46413 9.10684 9.29931C8.93771 9.14417 8.73316 9.11479 8.52458 9.20723C8.31601 9.29967 8.2035 9.46198 8.16733 9.7049H8.16624Z"
				                    fill="#0060FE"
				                  />
				              	</svg>
				          	</div><a href="https://www.facebook.com/groups/740534523911091" target="_blank" class="quick-widget-community-link">Join our Community</a></li>
				          	<li>
				          		<div class="list_icon" style="background-color: rgba(152, 190, 0, 0.15);">
				          			<svg width="15" height="13" viewBox="0 0 15 13" fill="none" xmlns="http://www.w3.org/2000/svg">
				          				<path d="M14.1991 6.08468C14.088 6.32262 13.8965 6.40304 13.6394 6.39229C13.3061 6.37858 12.975 6.39007 12.6424 6.38859C12.3746 6.38859 12.1838 6.21551 12.1798 5.97645C12.1757 5.7374 12.3698 5.55728 12.6461 5.55691C12.9831 5.55691 13.3205 5.56765 13.6569 5.5532C13.9121 5.54208 14.0935 5.62732 14.1991 5.86267V6.08468Z" fill="#98BE00"/>
				          				<path d="M6.16027 9.20862C6.12768 9.26199 6.10101 9.30424 6.07619 9.3476C5.4369 10.4553 4.79786 11.5631 4.15907 12.671C4.13833 12.7081 4.11796 12.7451 4.09611 12.7785C3.95943 12.9971 3.73609 13.062 3.51052 12.9367C2.90902 12.6032 2.30924 12.2668 1.71119 11.9275C1.46414 11.7867 1.41191 11.5569 1.56081 11.2975C2.00527 10.5251 2.45035 9.75319 2.89605 8.98179L2.97606 8.84133C2.94568 8.81909 2.91902 8.79611 2.88902 8.77758C2.6578 8.64004 2.46256 8.44949 2.31936 8.22164C2.27047 8.1427 2.21602 8.1212 2.12898 8.12157C1.78749 8.12157 1.44488 8.13084 1.10412 8.11008C0.812864 8.08923 0.539677 7.96105 0.33738 7.75034C0.135082 7.53963 0.0180427 7.26135 0.00888928 6.9693C-0.00296309 6.30415 -0.00296309 5.63851 0.00888928 4.97237C0.0203713 4.32748 0.554839 3.82677 1.22376 3.81565C1.52859 3.81046 1.83378 3.81195 2.13861 3.81565C2.17423 3.8191 2.21007 3.81214 2.24182 3.79563C2.27357 3.77912 2.29986 3.75377 2.31751 3.72262C2.65345 3.22784 3.12199 2.97581 3.72164 2.97544C4.40538 2.97544 5.08911 2.97804 5.77285 2.97285C5.85424 2.97098 5.93375 2.948 6.0036 2.90614C7.53255 1.9729 9.05978 1.0372 10.5853 0.0990233C10.7423 0.00266077 10.8983 -0.0410736 11.0668 0.0497295C11.2427 0.144239 11.289 0.30509 11.289 0.49448C11.2875 4.14192 11.2875 7.78925 11.289 11.4364C11.289 11.6247 11.2479 11.7859 11.0734 11.8845C10.899 11.9831 10.7401 11.9316 10.5797 11.8356C9.1525 10.9839 7.72441 10.1342 6.29546 9.28645C6.25583 9.26347 6.21546 9.24086 6.16027 9.20862ZM10.446 10.7856V1.17013C10.4053 1.19237 10.3771 1.20719 10.3505 1.22276C9.07089 2.00675 7.79244 2.79198 6.5151 3.57845C6.48989 3.59787 6.46914 3.62247 6.45425 3.65061C6.43936 3.67874 6.43068 3.70975 6.4288 3.74153C6.42436 5.25331 6.42621 6.76509 6.42324 8.27686C6.42013 8.31507 6.42879 8.35332 6.44806 8.38645C6.46733 8.41959 6.49629 8.44602 6.53103 8.46218C7.65947 9.1293 8.7868 9.79853 9.91303 10.4699C10.0853 10.5729 10.2586 10.6748 10.446 10.7856V10.7856ZM5.58099 8.21571V3.80935H3.76942C3.22051 3.80935 2.86457 4.15737 2.86309 4.70441C2.86087 5.54993 2.86087 6.39545 2.86309 7.24097C2.86309 7.75984 3.24051 8.18866 3.75646 8.21015C4.35982 8.23424 4.9654 8.21571 5.58099 8.21571ZM3.57349 12.0194C4.1424 11.0343 4.70835 10.0533 5.28653 9.05073H5.14467C4.74317 9.05073 4.34167 9.0537 3.94017 9.04851C3.90247 9.04443 3.86444 9.05238 3.83151 9.07122C3.79859 9.09005 3.77245 9.11881 3.75683 9.15339C3.35237 9.86277 2.94198 10.5692 2.53456 11.2767C2.5127 11.3138 2.49381 11.3553 2.47085 11.3998L3.57349 12.0194ZM2.02601 4.65141C1.73415 4.65141 1.45784 4.64177 1.18227 4.65437C1.09032 4.65622 1.00279 4.69426 0.938663 4.76023C0.874534 4.82621 0.838966 4.91481 0.839667 5.00684C0.834481 5.64926 0.834481 6.29167 0.839667 6.93409C0.839667 7.10124 0.960042 7.26209 1.11486 7.27099C1.41636 7.28878 1.71933 7.27618 2.02601 7.27618V4.65141Z" fill="#98BE00"/>
				          				<path d="M13.0036 2.6377C13.2259 2.6477 13.3566 2.72146 13.43 2.87971C13.5033 3.03797 13.4892 3.19549 13.3718 3.31853C13.0824 3.62195 12.7861 3.91845 12.4829 4.20803C12.3229 4.36073 12.0729 4.33849 11.9206 4.18246C11.8463 4.10788 11.8038 4.00742 11.8018 3.90213C11.7999 3.79684 11.8388 3.69489 11.9103 3.61763C12.1947 3.32113 12.4847 3.03167 12.7821 2.74888C12.8492 2.68328 12.9559 2.65919 13.0036 2.6377Z" fill="#98BE00"/>
				          				<path d="M12.2749 7.63037C12.3249 7.65631 12.4331 7.68596 12.5045 7.75379C12.792 8.02657 13.0712 8.30973 13.3475 8.59288C13.3869 8.63063 13.4182 8.67589 13.4398 8.72599C13.4613 8.77608 13.4726 8.82999 13.4729 8.88452C13.4733 8.93906 13.4627 8.9931 13.4418 9.04347C13.4209 9.09383 13.3901 9.13949 13.3512 9.17773C13.1872 9.34414 12.9327 9.34599 12.7564 9.17328C12.4764 8.89902 12.1995 8.62179 11.9256 8.3416C11.8643 8.28409 11.823 8.20852 11.8075 8.12588C11.7921 8.04324 11.8033 7.95782 11.8397 7.88202C11.9093 7.71561 12.0434 7.64149 12.2749 7.63037Z" fill="#98BE00"/>
				          			</svg>

		              			</div><a href="https://www.themehigh.com/docs/support/" target="_blank" class="quick-widget-support-link">Get support</a></li>
			       	 	</ul>
			   		</div>
				</div>
			<div id="myWidget" class="widget-popup" onclick="thwecWidgetPopUp()">
				<span id="th_quick_border_animation"></span>
				<div class="widget-popup-icon" id="th_arrow_head">
					<svg width="28" height="28" viewBox="0 0 28 28" fill="none" xmlns="http://www.w3.org/2000/svg">
						<path
						d="M10.1279 5.1957L0 15.3236L2.92808 18.2517L13.056 8.12378L10.1279 5.1957Z"
						fill="white"
						/>
			            <path
			            d="M19.8695 4.54623L7.83801 16.5777L10.7717 19.5113L22.8031 7.47991L19.8695 4.54623Z"
			            fill="white"
			            />
              			<path
                		d="M24.4214 9.0978L20.8551 12.6641L23.7888 15.5978L27.3439 12.0427L24.4214 9.0978Z"
                		fill="white"
              			/>
              			<path
		                d="M19.226 14.2932L15.6709 17.8483L18.6046 20.782L22.1597 17.2268L19.226 14.2932Z"
		                fill="white"
              			/>
              			<path
		                d="M15.3236 -7.92623e-06L11.7573 3.56631L14.6854 6.49439L18.2405 2.93927L15.3236 -7.92623e-06Z"
		                fill="white"
             			/>
             		</svg>
             	</div>
            </div>
            </div>
        <?php
	}
}

endif;