<?php
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_EDD_Updater_Helper')):

class THWEC_EDD_Updater_Helper {
	protected static $_instance = null;

	public $file             = '';
	public $data          = array();


	public function __construct($file, $data){
		// $plugin_header = $this->read_plugin_header($file);
		// $this->version = $plugin_header['Version'];

		// $this->name        = plugin_basename($file);
		$this->plugin_file  = $file;
		$this->api_url      = trailingslashit($data['api_url']);
		$this->product_id   = $data['item_id'];
		$this->product_name = $data['product_name'];
		$this->admin_asset_url = $data['admin_asset_url'];

		// $this->wp_override = isset( $data['wp_override'] ) ? (bool) $data['wp_override'] : false;
		// $this->beta        = isset( $data['beta'] ) ? (bool) $data['beta'] : false;

		$this->support_url = 'https://help.themehigh.com/hc/en-us/requests/new';

		$this->license_page_url = isset($data['license_page_url']) ? $data['license_page_url'] : '';

		$this->sw_identifier = $this->prepare_software_identifier($this->product_name);
		$this->license_data_key = $this->sw_identifier . '_license_data';

		if(is_multisite()){
			$this->domain = str_ireplace(array( 'http://', 'https://' ), '', network_site_url()); // blog domain name
		}else{
			$this->domain = str_ireplace(array( 'http://', 'https://' ), '', home_url()); // blog domain name
		}
		$this->invalid_license = false;

		//add_action('admin_init', array($this, 'save_activation_time'));
		add_action('admin_init', array($this, 'prepare_license_form_shortcode'));
		add_action('init', array($this ,'license_form_listener'), 99);
		add_action('admin_notices', array($this ,'display_admin_notices'), 9999);
		add_action('admin_init', array( $this, 'log_developer_data'));
		add_action('wp', array($this, 'schedule_license_status_check_daily_cron'));
		add_action('check_license_' . $this->sw_identifier, array($this, 'check_license'));
		add_action('admin_init', array( $this, 'handle_invalid_use'));
		add_action('admin_init', array($this, 'dismiss_notice'));
		add_action('admin_head', array( $this, 'custom_css'));

	}

	public static function instance($file, $data) {
		if(is_null( self::$_instance )) {
			self::$_instance = new self($file, $data);
		}
		return self::$_instance;
	}

	private function write_log ( $log ){
		if (defined('WP_DEBUG') && true === WP_DEBUG) {
			if ( is_array( $log ) || is_object( $log ) ) {
				error_log( print_r( $log, true ) );
			} else {
				error_log( $log );
			}
		}
	}

	public function save_activation_time(){
		$now = time();
		if(is_multisite()){
			$result = update_site_option('thwec_since', $now, 'no');
		}else{
			$result = update_option('thwec_since', $now, 'no');
		}

		if($result){
			return $now;
		}
	}

	private function get_activation_time(){
		$thwec_since = false;
		if(is_multisite()){
			$thwec_since = get_site_option('thwec_since');
		}else{
			$thwec_since = get_option('thwec_since');
		}

		if(!$thwec_since){
			$thwec_since = $this->save_activation_time();
		}

		return $thwec_since;
	}

	private function get_expiry_time_without_license(){
		$thwec_since = $this->get_activation_time();
		$delay = apply_filters($this->sw_identifier . '_without_license', 7 * DAY_IN_SECONDS);
		return $thwec_since + $delay;
	}

	private function prepare_software_identifier($product_name){
		$product_name = preg_replace("/\s+/", "_", $product_name);
		$sw_identifier = str_replace("-", "_", $product_name);
		$sw_identifier = 'th_'. sanitize_key($sw_identifier);
		return $sw_identifier;
	}

	function log_developer_data(){
		if (defined('WP_DEBUG') && true === WP_DEBUG &&  apply_filters( 'thedd_license_client_log_developer_data', false )) {
			$this->write_log('----- Developer tips start -----');
			$this->write_log('Software identifier: ' . $this->sw_identifier);
			$this->write_log('License form shortcode: [' . $this->sw_identifier . '_license_form]');
			$this->write_log('Option table key for license data: ' . $this->license_data_key);
			$this->write_log('License notice expiry time span key: ' . $this->sw_identifier . '_notice_expiry');
			$this->write_log('----- Developer tips end -----');
		}
	}

	function update_license_data($data){
		if(empty($data)){
			if(is_multisite()){
				delete_site_option($this->license_data_key);
			}else{
				delete_option($this->license_data_key);
			}
		}else{
			$existing_data = $this->get_license_data();
			$updated_data = array_merge($existing_data, $data);
			if(is_multisite()){
				update_site_option($this->license_data_key, $updated_data, 'no');
			}else{
				update_option($this->license_data_key, $updated_data, 'no');
			}
		}
	}

	public function get_license_data(){
		$license_data = false;
		if(is_multisite()){
			$license_data = get_site_option($this->license_data_key);
		}else{
			$license_data = get_option($this->license_data_key);
		}
		return is_array($license_data) && !empty($license_data) ? $license_data : array();
	}


	public function prepare_license_form_shortcode(){
		add_shortcode( $this->sw_identifier . '_license_form', array($this, 'license_form_shortcode_callback') );
	}

	public function license_form_shortcode_callback($atts){
		$params = shortcode_atts( array(
			'wrapper_class' => 'th-license-form-wrap',
		), $atts );
		ob_start();
		$this->output_license_page($params);
		return ob_get_clean();
	}

	public function output_license_page($params){
		$wrapper_class = $params['wrapper_class'];
		$license_data = $this->get_license_data();
		$status = isset($license_data['status']) ? $license_data['status'] : false;
		$license_key = isset($license_data['license_key']) ? $license_data['license_key'] : false;

		$license_form_banner_image = $this->admin_asset_url.'images/license/license_form_banner.png';

		echo '<div class="wrap">';
		echo '<h2></h2>';
		?>
		<style>
			.th-license-form-wrap a{color: #03A2E2 !important;transition: 0.2s;}
			.th-license-form-wrap a:hover{color: #00648C !important;}
			.th-license-form-wrap .button-primary:active {
				background: #03A2E2;
				background-color: #03A2E2;
				border-color: #d97426;
			}
			.th-license-form-wrap input[name="license_key"]:focus {
				border-color: #03A2E2;
				box-shadow: 0 0 0 1px #03A2E2;
			}
			.th-license-form-wrap .button-primary:focus{border: 1px solid #03A2E2 !important;  box-shadow: 0 0 0 1px #fff,0 0 0 3px #03A2E2 !important;}
		</style>
		<?php if( $license_key && (($status === 'valid') || ($status === 'active')) ){ ?>
			<style>
				.th-license-form input[name="license_key"]:focus{border: 1px solid #19B272;box-shadow: 0 0 0 1px #19B272}
				.th-license-form-wrap .button-primary:focus{border: 1px solid #19B272 !important; box-shadow: 0 0 0 1px #fff,0 0 0 3px #19B272 !important;}
			</style>
		<?php }elseif($license_key){ ?>
			<style>
				.th-license-form input[name="license_key"]:focus{border: 1px solid #FF5E54;box-shadow: 0 0 0 1px #FF5E54}
				.th-license-form-wrap .button-primary:focus{border: 1px solid #FF5E54 !important; box-shadow: 0 0 0 1px #fff,0 0 0 3px #FF5E54 !important;}
			</style>			
		<?php } ?>
		<div style="clear: both; background-color: #001D47; color: #fff; padding: 1.4rem 2rem; border-top-left-radius: 10px; border-top-right-radius: 10px; background-image: url(<?php echo $license_form_banner_image; ?>); background-position: bottom right; background-repeat: no-repeat;">
			<h1 style="color:#fff">Software License Key</h1>
			<?php if(!$license_key){ ?>
				<p style="margin-top: 0px;">Activate License to get auto-updates, premium support & unlimited access to premium features.</p>
			<?php }else if( $status === 'expired' ){ ?>
				<p style="position: relative; margin-top: 0px;">
					<?php $message = "Your license for the <strong>%s</strong> is expired.";
					printf($message, $this->product_name); ?>
					<img style="position: absolute;margin-left: 6px;" src="<?php echo $this->admin_asset_url; ?>images/license/sad.svg" />
				</p>
			<?php }else{ ?>
				<p style="position: relative; margin-top: 0px;">
					<?php $message = "Your license for the <strong>%s</strong> is activated.";
					printf($message, $this->product_name); ?>
					<img style="position: absolute;margin-left: 6px;" src="<?php echo $this->admin_asset_url; ?>images/license/smily.svg" />
				</p>
			<?php } ?>
		</div>

		<div style="clear: both; padding: 1rem 2rem 2rem 2rem; background-color: #fff; box-shadow: 1px 1px 5px 1px rgba(0,0,0,.1); min-height: 240px;border-bottom-left-radius: 10px; border-bottom-right-radius: 10px;">
			<div class="<?php echo $wrapper_class; ?>">
				<?php if($license_key){ ?>
				<p>Deactivate License Key so that it can be used on another domain.</p>
				<?php } ?>

				<?php
				$this->output_license_form($license_data);
				?>
			</div>
			<div>
				<?php
				$this->output_license_info($license_data, $license_key);
				?>
			</div>
			<div style="clear: both;"></div>
		</div>
		</div>
		<?php
	}

	private function output_license_form($license_data){
		$license_key = isset($license_data['license_key']) ? $license_data['license_key'] : '';
		$status = isset($license_data['status']) ? $license_data['status'] : false;

		$input_style = 'width: 560px; padding: 8px;';
		$license_field_attr  = 'name="license_key"';
		$license_field_attr .= ' placeholder="License key ( e.g. LDXXRJZQ341X9TH9GFMADYDAA15PE8 )"';
		$form_title_note = '';
		$form_footer_note = '';

		if($license_key){
			$license_field_attr .= ' value="'.$license_key.'"';
			$license_field_attr .= ' readonly';
			$btn_label  = 'Deactivate';
			$btn_action = 'deactivate';
			$form_footer_note = '';

			//$this->display_expiry_notices($license_data);
		}else{
			$invalid_license_key = '';
			if( $this->invalid_license === "invalid" ){
				$invalid_license_key = isset($_POST['license_key']) ? sanitize_textarea_field($_POST['license_key']) : '';
				$input_style .= ' border: 1px solid #FF5E54;';
			}
			$license_field_attr .= 'value="'.$invalid_license_key.'"';
			$btn_label  = 'Activate';
			$btn_action = 'activate';
		}
		$btn_action .= '-'.$this->sw_identifier;

		if( $license_key &&  (($status === 'valid') || ($status === 'active')) ){
			$input_style .= ' border: 1px solid #19B272;';
			$input_style .= ' background-color: #F8FFFC;';
		}elseif($license_key){
			$input_style .= ' border: 1px solid #FF5E54;';
			$input_style .= ' background-color: #FBF4F3;';
		}

		//$this->print_validation_notices();
		$account_svg = $this->admin_asset_url.'images/license/account.svg';
		$locked_svg = $this->admin_asset_url.'images/license/locked.svg';
		$key_svg = $this->admin_asset_url.'images/license/key.svg';
		$unlocked_svg = $this->admin_asset_url.'images/license/unlocked.svg';

		$box_style = 'margin-top: 20px; padding: 20px 30px 10px 30px; background-color: #fff; box-shadow: 1px 1px 5px 1px rgba(0,0,0,.1); min-height: 240px;';
		?>
		<?php if(!$license_key){ ?>
			<h2>Follow the below steps to activate license</h2>
			<ol class="thpladmin-license-steps" style="margin: 20px 0; list-style-type: none;">
				<li style="margin-bottom: 12px; padding:  0 0 4px 28px; background-image: url(<?php echo $account_svg; ?>); background-repeat: no-repeat;">Login in to <a href="https://www.themehigh.com/login/" target="_blank">ThemeHigh account</a>.</li>
				<li  style="margin-bottom: 12px; padding:  0 0 4px 28px; background-image: url(<?php echo $locked_svg; ?>); background-repeat: no-repeat;">From the <b>My Account</b> page, go to the dashboard.</li>
				<li  style="margin-bottom: 12px; padding:  0 0 4px 28px; background-image: url(<?php echo $key_svg; ?>); background-repeat: no-repeat;">Click on the <b>Licence Key</b> tab.</li>
				<li  style="margin-bottom: 12px; padding:  0 0 4px 28px; background-image: url(<?php echo $unlocked_svg; ?>); background-repeat: no-repeat;">Click on the corresponding licence keys of the plugin and copy.</li>
			</ol>
		<?php } ?>
		<?php echo $form_title_note; ?>
		<form method='post' action='' id="th_license_form" class="th-license-form">
			<?php echo wp_nonce_field('handle_license_form', 'nonce_license_form'); ?>

			<div class="th-license-form-field-wrap" style="position: relative;">
				<input type="text" <?php echo $license_field_attr ?> style="<?php echo $input_style; ?>">

				<?php if(!$license_key){ ?>
					<button type="submit" name="action" value="<?php echo $btn_action; ?>" class="button-primary" style="padding:8px; width:140px; margin-left: 10px; background-color: #03A2E2; border: 1px solid #03A2E2;"><?php echo $btn_label; ?></button>
				<?php } else { ?>
					<input type="hidden" name="action" value="<?php echo $btn_action; ?>" />
						<?php if( ($status === 'valid') || ($status === 'active') ){ ?>
							<img style="position: relative;top: 5px;margin-left: 15px;" src="<?php echo $this->admin_asset_url; ?>images/license/valid.svg" /> <span style="color: #19B272;font-weight: bold;"><?php echo ucwords($status); ?></span>
						<?php }else{ ?>
							<img style="position: relative;top: 5px;margin-left: 15px;" src="<?php echo $this->admin_asset_url; ?>images/license/invalid.svg" /> <span style="color: #FF5E54;font-weight: bold;"><?php echo ucwords($status); ?></span>
						<?php } ?>
				<?php } ?>
			</div>
		</form>
		<?php if($this->invalid_license === 'invalid'){
			echo '<p style="font-style: italic; color: #FF5E54;">Invalid License key</p>';
		} ?>
		<?php if(!$license_key){ ?>
		<p>
			<p>If you are still having trouble activating your license key, please check the <a href="https://help.themehigh.com/hc/en-us/articles/4406546358169-Manage-License" target="_blank">documentation</a> or contact our <a href="<?php echo $this->support_url; ?>" target="_blank">customer experience team</a> for assistance.</p>			
		</p>
		<?php } ?>		
		<?php echo $form_footer_note; ?>
		<?php
	}

	private function output_license_info($license_data, $license_key){
		$status = isset( $license_data['status'] ) ? $license_data['status'] : '';

		if($license_key){
			$expiry = isset( $license_data['expiry'] ) ? $license_data['expiry'] : '';
			$wp_date_format = get_option('date_format');
			if($wp_date_format && $expiry && $this->valid_date_format($expiry)){
				$expiry = date_format(date_create($expiry), $wp_date_format);
			}elseif($expiry == 'lifetime'){
				$expiry = 'Lifetime';
			}

			if($expiry && ( ($status === 'valid') || ($status === 'active') )){ ?>
				<p style="font-style: italic;">Expires: <?php echo $expiry; ?></p>
			<?php }elseif($expiry){ ?>
				<p style="font-style: italic; color: #FF5E54;">Expired: <?php echo $expiry; ?></p>
			<?php } ?>
			<p><a href="javascript:document.getElementById('th_license_form').submit();">Deactivate this License Key</a></p>
		<?php
		}
	}


	public function license_form_listener() {
		if(isset($_POST['nonce_license_form']) && $_POST['nonce_license_form']){
			if(!wp_verify_nonce($_POST['nonce_license_form'], 'handle_license_form')){
				die('You are not authorized to perform this action.');

			} else {
				$action = isset($_POST['action']) ? $_POST['action'] : '';
				if($action === 'activate-'.$this->sw_identifier){
					$license_key = isset($_POST['license_key']) ? $_POST['license_key'] : '';
					if($license_key){
						$this->trigger_license_request('activate', $_POST);
					}else{
						//$this->handle_notices('E003');
					}
				}elseif($action === 'deactivate-'.$this->sw_identifier){
					$this->trigger_license_request('deactivate', $_POST);
				}

			}
		}
	}

	private function trigger_license_request($action, $posted){
		// data to send in our API request
		$request_data = $this->prepare_request_data($action, $posted);	

		//$request = wp_remote_post( $target_url, array('body' => $request_data) );
		$request = wp_remote_post($this->api_url, array( 'timeout' => 15, 'sslverify' => false, 'body' => $request_data ));

		if(is_wp_error($request) || wp_remote_retrieve_response_code($request) != 200){
			//$this->handle_notices('E002');
			$this->write_log('--- Start of error ' . $action . '');
			$this->write_log($request);
			$this->write_log('--- End of error ---');
		} else {
			$response = wp_remote_retrieve_body( $request );
			$response_obj = json_decode($response);

			$this->write_log("************");
			$this->write_log($response_obj);
			$this->write_log("************");

			if ( $response_obj && (false === $response_obj->success) ) {
				if(isset($response_obj->error)){
					switch( $response_obj->error ) {

						case 'expired' :
							$message = __( 'Your license key expired.' );
							break;

						case 'disabled' :
						case 'revoked' :

							$message = __( 'Your license key has been disabled.' );
							break;

						case 'missing' :
							$this->invalid_license = 'invalid';
							$message = __( 'Invalid license.' );
							break;

						case 'invalid' :
						case 'site_inactive' :
							$this->invalid_license = $response_obj->error;
							$message = __( 'Your license is not active for this URL.' );
							break;

						case 'item_name_mismatch' :

							$message = sprintf( __( 'This appears to be an invalid license key for %s.' ), $this->product_name );
							break;

						case 'no_activations_left':

							$message = __( 'Your license key has reached its activation limit.' );
							break;

						default :

							$message = __( 'An error occurred, please try again.' );
							break;
					}

					switch( $response_obj->error ) {
						case 'expired' :
							$license_data = $this->prepare_data_from_response($response_obj);
							$license_data['license_key'] = isset($posted['license_key']) ? $posted['license_key'] : '';
							$license_data['status'] = 'expired';
							$this->update_license_data($license_data);
							break;

						case 'disabled' :
						case 'revoked' :
						case 'missing' :
						case 'invalid' :
						case 'site_inactive' :
						case 'item_name_mismatch' :
						case 'no_activations_left':
						default :
							$this->update_license_data(array());
							break;
					}

				}else{
					$message = __( 'An error occurred, please try again.' );
					$this->update_license_data(array());
				}
				// add_action('admin_notices', function() use ($message){
				// 	echo '<div class="notice notice-error"><p>'. $message. '</p></div>';
				// });

			}else{
				if($action == 'activate'){
					$message = __('License activated successfully.', 'th_edd_license_helper');
					$license_data = $this->prepare_data_from_response($response_obj);
					$license_data['license_key'] = isset($posted['license_key']) ? $posted['license_key'] : '';
					$this->update_license_data($license_data);
				}elseif($action == 'deactivate'){
					$message = __('License deactivated successfully.', 'th_edd_license_helper');
					$this->update_license_data(array());
				}

				// add_action('admin_notices', function() use ($message) {
				// 	echo '<div class="notice notice-success"><p>'. $message. '</p></div>';
				// });
			}

		}

	}


	public function prepare_request_data($action, $posted){
		// Validate Posted Data & create data array to POST to API
		$license_key = isset($posted['license_key']) ? $posted['license_key'] : '';
		$license_key = trim($license_key);
		if($action == 'activate'){

			$api_params = array(
				'edd_action'  => 'activate_license',
				'license'     => $license_key,
				'item_id'     => $this->product_id,
				'url'         => $this->domain,
				'environment' => function_exists( 'wp_get_environment_type' ) ? wp_get_environment_type() : 'production',
			);

		}elseif($action == 'deactivate'){

			$api_params = array(
				'edd_action'  => 'deactivate_license',
				'license'     => $license_key,
				'item_id'     => $this->product_id,
				'url'         => $this->domain,
				'environment' => function_exists( 'wp_get_environment_type' ) ? wp_get_environment_type() : 'production',
			);

		}
		return $api_params;
	}

	function prepare_data_from_response($response_obj){
		return array(
			'status' => $response_obj->license,
			'expiry' => $response_obj->expires,
			/*
			'license_limit' => $response_obj->license_limit,
			'site_count' => $response_obj->site_count,
			'activations_left' => $response_obj->activations_left,
			*/
		);
	}

	function valid_date_format($date, $format = 'Y-m-d H:i:s')
	{
	    $d = DateTime::createFromFormat($format, $date);
	    // The Y ( 4 digits year ) returns TRUE for any integer with any number of digits so changing the comparison from == to === fixes the issue.
	    return $d && $d->format($format) === $date;
	}


	function schedule_license_status_check_daily_cron() {
		if(!wp_next_scheduled( 'check_license_' . $this->sw_identifier )){
			wp_schedule_event(time(), 'daily', 'check_license_' . $this->sw_identifier);
		}
	}


	/**
	 * Checks if a license key is still valid.
	 * The updater does this for you, so this is only needed if you want
	 * to do somemthing custom.
	 *
	 * @return void
	 */
	function check_license() {

		$saved_license_data = $this->get_license_data();
		$license_key = isset($saved_license_data['license_key']) ? $saved_license_data['license_key'] : false;

		if(!$license_key){
			return;
		}

		$api_params = array(
			'edd_action'  => 'check_license',
			'license'     => $license_key,
			'item_id'     => $this->product_id,
			'url'         => $this->domain,
			'environment' => function_exists( 'wp_get_environment_type' ) ? wp_get_environment_type() : 'production',
		);

		// Call the custom API.
		$response = wp_remote_post(
			$this->api_url,
			array(
				'timeout'   => 15,
				'sslverify' => false,
				'body'      => $api_params,
			)
		);

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$response_obj = json_decode(wp_remote_retrieve_body($response));

		// if(!$response_obj->success){
		// 	$this->update_license_data(array());
		// 	return false;
		// }

		$new_data = array(
			'status' => $response_obj->license,
			'expiry' => $response_obj->expires,
			/*
			'license_limit' => $response_obj->license_limit,
			'site_count' => $response_obj->site_count,
			'activations_left' => $response_obj->activations_left,
			*/
		);

		$new_license_data = array_replace($saved_license_data, $new_data);

		if($new_license_data != $saved_license_data){
			$this->update_license_data($new_license_data);
		}
	}


	public function display_admin_notices() {
		if(!apply_filters('themehigh_show_admin_notice', true, $this->sw_identifier )){
			return;
		}

		$license_data = $this->get_license_data();

		$license_key = isset($license_data['license_key']) ? $license_data['license_key'] : false;

		if($license_data && $license_key){

			
		}else{
			$expiry_time = $this->get_expiry_time_without_license();
			$now = time();

			if($now < $expiry_time){
				$expiry_date = wp_date(get_option( 'date_format' ), $expiry_time);
				$notice_text = "An active ThemeHigh license is required for the <span style='font-size:15px'><strong>%s</strong></span> to work with your WordPress. If you haven’t activated the license yet, please activate it from <a style='text-decoration:none;' href='%s'>here</a> before <span style='font-size:15px'><strong>%s</strong></span> for an uninterrupted experience.";
				$notice = sprintf($notice_text, $this->product_name, $this->license_page_url, $expiry_date);
			}else{

				$notice_text = "We can’t find an active ThemeHigh license for <span style='font-size:15px'><strong>%s</strong></span> in your WordPress. Activate your license key <a style='text-decoration:none;' href='%s'>here</a> if you missed it. If this is any error or you are facing an issue, <a style='text-decoration:none;' href='%s' target='_blank'>get in touch</a> with support team.";
				$notice = sprintf($notice_text, $this->product_name, $this->license_page_url, $this->support_url);
			}
		}

		if(!empty($notice)){
			if(is_multisite()){
				$enable_notification_sub_site = apply_filters( 'themehigh_enable_notifications_sub_site', true, $this->sw_identifier );

				if(is_main_site()){
					$this->show_admin_notice_content($notice, 'admin_notice');
				}else{
					if($enable_notification_sub_site){
						$this->show_admin_notice_content($notice, 'admin_notice');
					}
				}
			}else{
				$this->show_admin_notice_content($notice, 'admin_notice');
			}
		}
	}

	private function show_admin_notice_content($notice, $type='admin_notice'){

		if(!$this->is_notice_visible()){
			return;
		}

		$style = "background-color: #001D47;";
		$style .= " color: #fff;";
		$style .= " width:100%;";
		$style .= " box-sizing: border-box;";
		$style .= " border:none;";

		$button_style = "box-sizing: border-box; display: inline-block; text-align: center; text-decoration: none; padding: 0; color: #fff";

		$themehigh_logo = $this->admin_asset_url.'/images/themehigh-logo.png';


		$close_url = add_query_arg(
			array(
				'th_dismiss_license_notice' => $this->sw_identifier,
				'_wpnonce' => wp_create_nonce($this->sw_identifier . '_dismiss_license_notice'),
			)
		);
		?>

		<div class="notice notice-info <?php echo $this->sw_identifier . '_admin_notice '; ?>thpl_license_notice" style="<?php echo $style; ?>">
			<style>
				.thpl_license_notice a{color: #1f9bff}
				.thpl_license_notice a:hover{color: #2d81c5}
			</style>
			<div style="display: grid;width: 100%;grid-template-columns: 64px 1fr;">
				<div style="padding: 4px 0; position: relative; display: flex; align-items: center; "><img style="left: 10px; top: calc(50% - 10px);width: 50px;" src="<?php echo $themehigh_logo; ?>" /></div>

			  	<div style="width:100%; float:left; padding: 4px 0; position: relative;">
					<div class="thpladmin-notice" style="width:95%; float:left;">
						<p><?php _e($notice, 'themehigh-license'); ?></p>
					</div>
					<div class="" style="position: absolute; right: 0px; top: calc(50% - 15px);">
						<p style="margin:0"><a href="<?php echo $close_url; ?>" style="<?php echo $button_style; ?>"><span class="thpladmin-notice-close" style="border: 1px solid #133460; border-radius: 50%; width: 22px; height: 22px; line-height: 18px; display: inline-block; background-color: #133460; margin-right: 9px;"><span class="dashicons dashicons-no-alt"></span></span></a></p>
					</div>
			  	</div>
			</div>
		</div>
		<?php
	}

	public function dismiss_notice(){
		if(!wp_doing_ajax() && is_admin()){
			if(isset($_REQUEST['th_dismiss_license_notice']) && $_REQUEST['th_dismiss_license_notice'] ==  $this->sw_identifier){

				check_admin_referer($this->sw_identifier . '_dismiss_license_notice');

				$this->mark_notice_as_dismmised();
				if(wp_safe_redirect(esc_url(remove_query_arg(array('th_dismiss_license_notice', '_wpnonce'))))){
				    exit;
				}

			}
		}
	}

	private function is_notice_visible(){
		$now = time();
		if(is_multisite()){
			$notice_expiry = get_site_option($this->sw_identifier . '_notice_expiry', false);
		}else{
			$notice_expiry = get_option($this->sw_identifier . '_notice_expiry', false);
		}

		if(!$notice_expiry){
			return true;
		}

		if($now > $notice_expiry){
			return true;
		}

		return false;
	}

	private function mark_notice_as_dismmised(){
		$now = time();
		$expiry = $now + apply_filters($this->sw_identifier . '_notice_expiry', 1 * DAY_IN_SECONDS);

		if(is_multisite()){
			update_site_option($this->sw_identifier . '_notice_expiry', $expiry, 'no');
		}else{
			update_option($this->sw_identifier . '_notice_expiry', $expiry, 'no');
		}
	}

	public function handle_invalid_use(){

		if(!wp_doing_ajax() && is_admin()){

			$page  = isset( $_GET['page'] ) ? esc_attr( $_GET['page'] ) : '';
			$plugin_pages = array('th_email_customizer_templates','th_email_customizer_mapping','th_email_customizer_pro', 'th_email_customizer_license_settings', 'th_email_customizer_integrations');

			if(!in_array($page, $plugin_pages)){
				return;
			}
						
			$expiry_time = $this->get_expiry_time_without_license();
			$now = time();
			if($now < $expiry_time){
				return;
			}

			$limited_pages = array('th_email_customizer_templates','th_email_customizer_mapping','th_email_customizer_pro', 'th_email_customizer_integrations');

			$license_data = $this->get_license_data();		

			if($license_data){
				$status = isset($license_data['status']) ? $license_data['status'] : '';
				if(in_array($page, $limited_pages) && $page != 'th_email_customizer_license_settings'){
					if(!($status == 'valid' or $status == 'expired')){
				        wp_redirect($this->license_page_url, 301);
				        exit;
					}
				}
			}else{
				if(in_array($page, $limited_pages) && $page != 'th_email_customizer_license_settings'){
			        wp_redirect($this->license_page_url, 301);
			        exit;			
				}
			}

			// $page  = isset( $_GET['page'] ) ? esc_attr( $_GET['page'] ) : '';
			// $tab  = isset( $_GET['tab'] ) ? esc_attr( $_GET['tab'] ) : 'general_settings';
			// $limited_tabs = array('general_settings','display_settings','advanced_settings');
			// $license_data = $this->get_license_data();		
			// if($license_data){
			// 	$status = isset($license_data['status']) ? $license_data['status'] : '';
			// 	if($page == 'th_multi_step_checkout' && in_array($tab, $limited_tabs) && $tab != 'license_settings'){
			// 		if(!($status == 'valid' or $status == 'expired')){
			// 	        wp_redirect($this->license_page_url, 301);
			// 	        exit;
			// 		}		
			// 	}
			// }else{
			// 	if($page == 'th_multi_step_checkout' && in_array($tab, $limited_tabs) && $tab != 'license_settings'){
			//         wp_redirect($this->license_page_url, 301);
			//         exit;			
			// 	}
			// }

		}

	}

	public function custom_css(){
		if(!wp_doing_ajax()){
			$license_data = $this->get_license_data();		
			if($license_data){
				$status = isset($license_data['status']) ? $license_data['status'] : '';
				if(($status == 'valid')){
					return;
				}
			}
			$image = $this->admin_asset_url.'/images/license/license_warning.svg';
			?>
			<style>
				ul#adminmenu .th-license-warning-icon {
					width: 18px;
					height: 18px;
					background-image: url('<?php echo $image; ?>');
					position: absolute;
					margin-left: 5px;
					background-size: cover;
				}
			</style>
			<?php
		}
	}


}

endif;
