<?php
/**
 * The admin settings page for managing the third party integrations.
 *
 * @link       https://themehigh.com
 * @since      3.6.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_Integrations')):

class THWEC_Integrations{
	/**
	 * WC_Emails class instance
	 *
	 * @access   public
	 * @var      $woo_mailer  class instance
	 */
    public $woo_mailer = null;

    /**
	 * Manages the email customizer settings
	 *
	 * @access   protected
	 * @var      $settings    array of settings for customizer
	 */
    protected $settings = array();

     /**
	 * Manages the mapping between email template and emails
	 *
	 * @access   private
	 * @var      $template_map    email template map
	 */
    private $template_map = array();

     /**
	 * Manages the list of subjects for emails
	 *
	 * @access   private
	 * @var      $subjects    list of subjects
	 */
    protected $subjects = array();
    protected $admin_emails = array();
    private $replaced_placeholders = array();
    private $subject_placeholders = array();
    private $attachment_email_ids = array();
	/**
	 * Construct
	 */
	public function __construct() {
		$this->init_variables();
		add_action('after_setup_theme', array($this, 'define_subject_filters'));
		add_action('after_setup_theme', array($this, 'setup_woo_email_attachments'));
		add_filter('thwec_locate_integration_template', array($this, 'thwec_locate_woo_emails'),10, 4);
    	add_filter('thwec_woo_email_instances', array($this, 'get_compatible_woo_emails'));
	}

	public function define_subject_filters(){
		add_filter('woocommerce_email_subject_new_order', array($this, 'thwec_email_subject_new_order'), 1, 2);
		add_filter('woocommerce_email_subject_customer_processing_order', array($this, 'thwec_email_subject_processing'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_completed_order', array($this, 'thwec_email_subject_completed'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_invoice', array($this, 'thwec_email_subject_invoice'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_note', array($this, 'thwec_email_subject_customer_note'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_new_account', array($this, 'thwec_email_subject_new_account'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_on_hold_order', array($this, 'thwec_email_subject_on_hold'), 1, 2);
    	add_filter('woocommerce_email_subject_cancelled_order', array($this, 'thwec_email_subject_cancelled'), 1, 2);
    	if( version_compare( THWEC_Utils::get_wc_version(), '3.5.0', ">=" ) ){
    		add_filter('woocommerce_email_subject_customer_refunded_order', array($this, 'thwec_email_subject_refunded_with_partial'), 1, 3);
    	}else{
    		add_filter('woocommerce_email_subject_customer_refunded_order', array($this, 'thwec_email_subject_refunded'), 1, 2);
    	}
    	add_filter('woocommerce_email_subject_failed_order', array($this, 'thwec_email_subject_failed'), 1, 2);
    	add_filter('woocommerce_email_subject_customer_reset_password', array($this, 'thwec_email_subject_reset_password'), 1, 2);
	}

	public function setup_woo_email_attachments(){
		add_filter( 'woocommerce_email_attachments', array($this, 'thwec_woo_attachments'), 10, 4 );
	}

	public function get_compatible_woo_emails($emails){
		$woo_emails = array(
			"WC_Email_New_Order"					=>	"New order",
			"WC_Email_Cancelled_Order"				=>	"Cancelled order",
			"WC_Email_Failed_Order"					=>	"Failed order",
			"WC_Email_Customer_On_Hold_Order"		=>	"Order on-hold",
			"WC_Email_Customer_Processing_Order"	=>	"Processing order",
			"WC_Email_Customer_Completed_Order"		=>	"Completed order",
			"WC_Email_Customer_Refunded_Order"		=>	"Refunded order",
			"WC_Email_Customer_Invoice"				=>	"Customer invoice / Order details",
			"WC_Email_Customer_Note"				=>	"Customer note",
			"WC_Email_Customer_Reset_Password"		=>	"Reset password",
			"WC_Email_Customer_New_Account"			=>	"New account"
		);
		return array_merge($emails, $woo_emails);
	}

	private function init_variables(){
		$this->settings = THWEC_Utils::get_template_settings();
		$this->template_map = THWEC_Utils::get_template_map( $this->settings );
		$this->subjects = THWEC_Utils::get_template_subject( $this->settings );
		$this->admin_emails = array('new_order', 'failed_order', 'cancelled_order');
		$this->attachment_email_ids = array(
			'new_order',
			'cancelled_order',
			'failed_order',
			'customer_on_hold_order',
			'customer_processing_order',
			'customer_completed_order',
			'customer_refunded_order',
			'customer_partially_refunded_order',
			'customer_invoice',
			'customer_note',
			'customer_reset_password',
			'customer_new_account'
		);
	}

	protected function format_email_subject($subject, $status, $order){
		// replaced_placeholders
		if( isset( $this->subjects[$status] ) && !empty( $this->subjects[$status] ) ){
			$this->subject_placeholders = THWEC_Utils::get_subject_placeholders($order, $status);
			$raw_subject = $this->subjects[$status];
			$raw_subject = preg_replace_callback('/{(.+?)}/ix', array($this, "thwec_manage_subject_placeholders"), $raw_subject);
			if( !empty( $this->replaced_placeholders ) ){
				$subject = vsprintf( $raw_subject, $this->replaced_placeholders );
			}
		}
		return $subject;
	}

	private function thwec_manage_subject_placeholders($data){
		if( isset($data[0]) && isset($this->subject_placeholders[$data[0]])){
			array_push( $this->replaced_placeholders, $this->subject_placeholders[$data[0]]);
			return '%s';
		}
		return $data[0];

	}

	protected function format_email_subject1( $subject, $status, $order ){
		if( isset( $this->subjects[$status] ) && !empty( $this->subjects[$status] ) ){
			$subject = THWEC_Utils::format_subjects( $this->subjects[$status], $status, $order );
		}
		return $subject;
	}

	public function thwec_locate_woo_emails($found, $id, $name, $map){
		$key = str_replace('_', '-', $id);
		$key = in_array($id, $this->admin_emails) ? 'admin-'.$key : $key;
		if(isset($map[$key]) && !empty($map[$key])){
			$found = apply_filters('thwec_locate_wpml_template', $map[$key], $id, $name, $map);
		}
		return $found;
	}

	public function thwec_email_subject_new_order($subject, $order){
		return $this->format_email_subject($subject, 'admin-new-order', $order);
	}

	public function thwec_email_subject_processing($subject, $order){
		return $this->format_email_subject($subject, 'customer-processing-order', $order);
	}

	public function thwec_email_subject_completed($subject, $order){
		return $this->format_email_subject($subject, 'customer-completed-order', $order);
	}

	public function thwec_email_subject_invoice($subject, $order){
		return $this->format_email_subject($subject, 'customer-invoice', $order);
	}

	public function thwec_email_subject_customer_note($subject, $order){
		return $this->format_email_subject($subject, 'customer-note', $order);
	}

	public function thwec_email_subject_new_account($subject, $order){
		return $this->format_email_subject($subject, 'customer-new-account', $order);
	}

	public function thwec_email_subject_on_hold($subject, $order){
		return $this->format_email_subject($subject, 'customer-on-hold-order', $order);
	}

	public function thwec_email_subject_cancelled($subject, $order){
		return $this->format_email_subject($subject, 'admin-cancelled-order', $order);
	}

	public function thwec_email_subject_refunded_with_partial($subject, $order, $email){
		if( isset($email->id) && $email->id === "customer_partially_refunded_order" ){
			return $this->format_email_subject( $subject, 'customer-partially-refunded-order', $order );
		}
		return $this->format_email_subject($subject, 'customer-refunded-order', $order);
	}

	public function thwec_email_subject_refunded($subject, $order){
		return $this->format_email_subject($subject, 'customer-refunded-order', $order);
	}

	public function thwec_email_subject_failed($subject, $order){
		return $this->format_email_subject($subject, 'admin-failed-order', $order);
	}

	public function thwec_email_subject_reset_password($subject, $order){
		return $this->format_email_subject($subject, 'customer-reset-password', $order);
	}

    public function thwec_woo_attachments($attachments, $email_id, $order, $email){
    	$email_attachments = isset($this->settings[THWEC_Utils::get_email_attachment_key()]) ? $this->settings[THWEC_Utils::get_email_attachment_key()] : array();
    	$compatible_email_ids = apply_filters('thwec_woo_attachment_email_ids', $this->attachment_email_ids);
    	if( in_array($email_id, $compatible_email_ids) ){
	    	$email_attachment = isset($email_attachments[$email_id]) ? $email_attachments[$email_id] : false;
    		if( is_array( $email_attachment ) ){
    			foreach ($email_attachment as $index => $attachment) {
    				if( isset($attachment['file_url']) ){
    					$attachments[] = $attachment['file_url'];
    				}		
    			}
    		}
    	}
    	return $attachments;
    }
}

endif;

new THWEC_Integrations();