<?php
/**
 * This page manages the integration of Order Status Manager.
 *
 * @link       https://themehigh.com
 * @since      3.7.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_WooCommerce_Order_Status_Manager')):

class THWEC_WooCommerce_Order_Status_Manager extends THWEC_Integrations{
	/**
	 * List of WooCommerce order status manager emails
	 *
	 * @access   private
	 * @var      $wosm_emails    array of emails
	 */
    private $wosm_emails = array();

     /**
	 * Order status manager emails ID and name array
	 *
	 * @access   private
	 * @var      $compatibility_settings    array of ID and name
	 */
    private $compatibility_settings = array();

     /**
	 * Manages the data required to find the current order status manager email
	 *
	 * @access   private
	 * @var      $wc_status_manager_email    order status manager helper
	 */
    private $wc_status_manager_email = array();

	/**
	 * Construct
	 */
	public function __construct() {
		parent::__construct();
		$this->get_wosm_emails();
		add_filter('thwec_email_statuses', array($this, 'prepare_emails'), 10, 1);
		add_filter('thwec_set_compatibility_settings', array($this, 'wosm_compatibility_settings'), 10, 1);
		add_filter('wc_order_status_manager_order_status_email_replace_variables', array($this, 'prepare_status_name'), 999, 4);
		add_filter('thwec_locate_integration_template', array($this, 'wosm_email_mapping'), 10, 4);
		add_filter( 'thwec_woo_attachment_email_ids', array($this, 'thwec_wosm_attachment_emails'), 10, 1 );
		add_filter('thwec_woo_email_instances', array($this, 'get_compatible_woo_emails'));
	}
	public function get_wosm_emails(){
		$wosm_posts = get_posts([
		  'post_type' => 'wc_order_email',
		  'post_status' => 'publish',
		  'numberposts' => -1
		]);
		foreach ($wosm_posts as $key => $wosm_post) {
			if( isset($wosm_post->ID) && isset($wosm_post->post_title) ){
				$this->wosm_emails['wc_order_status_email_'.$wosm_post->ID] = $wosm_post->post_title;
				$this->compatibility_settings[$wosm_post->ID] = $wosm_post->post_name;
				$this->render_subject($wosm_post->ID);
			}
		}
	}
	public function prepare_emails($emails){
		
		return array_merge($emails, $this->wosm_emails);
	}

	public function wosm_compatibility_settings($compatibility_settings){
		return $this->compatibility_settings;
	}

	public function wosm_email_mapping($found, $template_id, $template_name, $map){
		if( $template_name == "emails/customer-order-status-email.php" && is_array($map) ){
			return isset($map[$template_id]) ? $map[$template_id] : false;
		}
		return $found;
	}

	private function render_subject($id){
		add_filter('woocommerce_email_subject_wc_order_status_email_'.$id, array($this, 'set_subject'), 1, 2);
	}

    public function prepare_status_name( $find, $id, $type, $object ){
		if( !empty( $id ) ){
			$this->wc_status_manager_email['id'] = $id;
		}
		return $find;	
	}

	public function set_subject($subject, $order){
		$id = isset( $this->wc_status_manager_email['id'] ) ? $this->wc_status_manager_email['id'] : false;
    	if( $id && isset( $this->subjects[$id] ) ){
    		$subject = THWEC_Utils::format_subjects( $this->subjects[$id], '', $order );
    	}
    	return $subject;
	}

	 public function thwec_wosm_attachments($attachments, $email_id, $order, $email){
    	$email_attachments = isset($this->settings[THWEC_Utils::get_email_attachment_key()]) ? $this->settings[THWEC_Utils::get_email_attachment_key()] : array();
    	$email_attachment = isset($email_attachments[$email_id]) ? $email_attachments[$email_id] : false;
    	if( is_array( $email_attachment ) ){
    		foreach ($email_attachment as $index => $attachment) {
    			if( isset($attachment['file_url']) ){
    				$attachments[] = $attachment['file_url'];
    			}		
    		}
    	}
    	return $attachments;
    }

    public function get_compatible_woo_emails($emails){
  		return array_merge($emails, $this->wosm_emails);
	}

	public function thwec_wosm_attachment_emails($ids){
		return array_merge($ids, array_keys($this->wosm_emails));
	}
}

endif;

new THWEC_WooCommerce_Order_Status_Manager();