<?php
/**
 * This page manages the integration of WooCommerce B2B.
 *
 * @link       https://themehigh.com
 * @since      3.7.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_WooCommerce_B2B')):

class THWEC_WooCommerce_B2B{

	/**
	 * Main instance of the class
	 *
	 * @access   protected
	 * @var      $_instance    
	 */
	protected static $_instance = null;

	/**
	 * WC_Emails class instance
	 *
	 * @access   public
	 * @var      $woo_mailer  class instance
	 */
    public $woo_mailer = null;

    /**
	 * Manages the email customizer settings
	 *
	 * @access   private
	 * @var      $settings    array of settings for customizer
	 */
    private $settings = array();

     /**
	 * List of b2b emails
	 *
	 * @access   private
	 * @var      $b2b_emails    array of emails
	 */
    private $b2b_emails = array();

	/**
	 * Construct
	 */
	public function __construct() {
		$this->b2b_emails = array(
			'wcb2b_new_quote'				=> 'New quote', 
			'wcb2b_customer_onquote_order'	=> 'On quote order',
			'wcb2b_customer_quoted_order'	=> 'Quoted order',
			'wcb2b_customer_status_notification' => 'Status notification'
		);
		$this->init_variables();
		add_filter('thwec_email_statuses', array($this, 'prepare_emails'), 10, 1);
		add_filter('thwec_locate_template_using_id', array($this, 'is_b2b_email'), 10, 2);
		add_filter('thwec_default_email_subjects', array($this, 'default_email_subject'), 10, 1);
		add_filter('woocommerce_email_subject_wcb2b_new_quote', array($this, 'thwec_subject_wcb2b_new_quote'), 1, 2);
		add_filter('woocommerce_email_subject_wcb2b_customer_onquote_order', array($this, 'thwec_subject_wcb2b_customer_onquote_order'), 1, 2);
		add_filter('woocommerce_email_subject_wcb2b_customer_quoted_order', array($this, 'thwec_subject_wcb2b_customer_quoted_order'), 1, 2);
		add_filter('woocommerce_email_subject_wcb2b_customer_status_notification', array($this, 'thwec_subject_wcb2b_customer_status_notification'), 1, 2);
		add_filter( 'thwec_woo_attachment_email_ids', array($this, 'thwec_wcb2b_attachment_emails'), 10, 1 );
		add_filter('thwec_woo_email_instances', array($this, 'get_compatible_woo_emails'));
		add_filter('thwec_locate_integration_template', array($this, 'woob2b_email_mapping'), 10, 4);
	}

	private function init_variables(){
		$this->settings = THWEC_Utils::get_template_settings();
		$this->template_map = THWEC_Utils::get_template_map( $this->settings );
		$this->subjects = THWEC_Utils::get_template_subject( $this->settings );
	}
	
	public function prepare_emails($emails){
		return array_merge($emails,$this->b2b_emails);
	}

	public function prepare_placeholders($email_content){
		$email_content = str_replace('{cwgisn_subscriber_name}', $this->getcwg_subscriber_name(), $email_content);
		$email_content = str_replace('{cwgisn_subscribed_product_name}', $this->getcwg_product_name(), $email_content);

		$email_content = str_replace('{cwgisn_subscribed_product_cart_link}', $this->getcwg_product_cart_url(), $email_content);
		return $email_content;
	}

	/**
	 * Template path for the email notification
	 *
	 * @param  string $t_name template name
	 * @return string template path found or boolean if not
	 */	
	public function get_email_template_path($t_name){
    	$tpath = false;
    	$email_template_path = THWEC_CUSTOM_TEMPLATE_PATH.$t_name.'.php';
    	if(file_exists($email_template_path)){
    		// $this->remove_default_hooks();
    	   	$tpath = $email_template_path;
    	}
    	return $tpath;
    }

	public function default_email_subject($subjects){
		$subjects['wcb2b_new_quote'] = 'A new quote request on {site_name} is received!';
		$subjects['wcb2b_customer_onquote_order'] = 'Your quote request on {site_name} is received!';
		$subjects['wcb2b_customer_quoted_order'] = 'Your quote request on {site_name} is processed!';
		$subjects['wcb2b_customer_status_notification'] = 'Your account on {site_name} is approved!';
		return $subjects;
	}

	public function is_b2b_email($is_b2b, $id){
		return isset($this->b2b_emails[$id]) ? true : $is_b2b;
	}

	public function thwec_subject_wcb2b_new_quote($subject, $order){
		$thwec_subject = isset($this->subjects['wcb2b_new_quote']) ? $this->subjects['wcb2b_new_quote'] : false;
		if( $thwec_subject ){
			$thwec_subject = $this->prepare_subject_placeholders($thwec_subject);
			return $thwec_subject;
		}
		return $subject;
	}

	public function thwec_subject_wcb2b_customer_onquote_order($subject, $order){
		$thwec_subject = isset($this->subjects['wcb2b_customer_onquote_order']) ? $this->subjects['wcb2b_customer_onquote_order'] : false;
		if( $thwec_subject ){
			$thwec_subject = $this->prepare_subject_placeholders($thwec_subject);
			return $thwec_subject;
		}
		return $subject;
	}

	public function thwec_subject_wcb2b_customer_quoted_order($subject, $order){
		$thwec_subject = isset($this->subjects['wcb2b_customer_quoted_order']) ? $this->subjects['wcb2b_customer_quoted_order'] : false;
		if( $thwec_subject ){
			$thwec_subject = $this->prepare_subject_placeholders($thwec_subject);
			return $thwec_subject;
		}
		return $subject;
	}

	public function thwec_subject_wcb2b_customer_status_notification($subject, $order){
		$thwec_subject = isset($this->subjects['wcb2b_customer_status_notification']) ? $this->subjects['wcb2b_customer_status_notification'] : false;
		if( $thwec_subject ){
			$thwec_subject = $this->prepare_subject_placeholders($thwec_subject);
			return $thwec_subject;
		}
		return $subject;
	}

	private function prepare_subject_placeholders($subject){
		$placeholders = array();
    	$placeholders['{site_name}'] = get_bloginfo();
    	$subject = THWEC_Utils::add_dynamic_data($placeholders, $subject);
		return $subject;
	}

	public function get_compatible_woo_emails($emails){
		$b2b_emails = array(
			'WCB2B_Email_New_Quote' 				=>	'New quote',
			'WCB2B_Email_Customer_OnQuote_Order'	=>	'On quote order',
			'WCB2B_Email_Customer_Quoted_Order'		=>	'Quoted order'
		);
		return array_merge($emails, $b2b_emails);
	}

	public function thwec_wcb2b_attachment_emails($id){
		return array_merge($id, array_keys($this->b2b_emails));
	}

	public function woob2b_email_mapping($found, $template_id, $template_name, $map){
		if( isset($map[$template_id]) ){
			return $map[$template_id];
		}
		return $found;
	}

}

endif;

new THWEC_WooCommerce_B2B();