<?php
/**
 * This page manages the integration of WPML plugin.
 *
 * @link       https://themehigh.com
 * @since      3.7.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_Wpml')):

class THWEC_Wpml extends THWEC_Integrations{
	/**
	 * Manages the current language set in WPML
	 *
	 * @access   private
	 * @var      $current_lang    WPML current language
	 */
	private $current_lang = null;

	/**
	 * Manages the default language set in WPML 
	 *
	 * @access   private
	 * @var      $wpml_default_lang    WPML default language
	 */
	private $wpml_default_lang = '';

	/**
	 * Construct
	 */
	public function __construct() {
		parent::__construct();
		$this->set_wpml_variables();
		add_filter('thwec_locate_wpml_template', array($this, 'wpml_email_mapping'), 10, 4);
		add_filter('thwec_get_script_data', array($this, 'get_script_contents'), 10, 2);
	}

	public function set_wpml_variables(){
		$this->wpml_default_lang = THWEC_Utils::get_wpml_locale( apply_filters( 'wpml_default_language', NULL ), true );
	}

	public function get_script_contents($script_var, $hook){
		if($hook != "email-customizer_page_th_email_customizer_pro"){
			return $script_var;
		}
		$wpml_vars = array(
			'wpml_active'				=> true,
			'wpml_integration_active'	=> THWEC_Utils::is_wpml_active(),
			'wpml_languages' 		 	=> icl_get_languages(),
			'wpml_lang_selected' 	 	=> isset( $_POST['thwec_template_lang'] ) ? sanitize_text_field( $_POST['thwec_template_lang'] ) : "",
			'wpml_default_language'  	=> THWEC_Utils::get_wpml_locale( apply_filters( 'wpml_default_language', NULL ), true )
		);
        return array_merge($wpml_vars, $script_var);
	}

	public function wpml_email_mapping($found, $id, $t_name, $map){
		if($found){
			$found = $this->get_wpml_template($found);
		}
		return $found;
	}

	private function get_wpml_template($found){
		$current_lang = strtolower(get_locale());
		$default_lang_template = $found.'-'.$this->wpml_default_lang;
		$current_lang_template = $found.'-'.$current_lang;
		if( $this->is_default_language_template($default_lang_template, $current_lang) ){
			$found = $default_lang_template;
		}else if( $this->is_a_language_template($current_lang_template, $current_lang) ){
			$found = $current_lang_template;
		}
		return $found;
	}

	private function is_default_language_template($name, $current_lang){
		if( !empty($this->wpml_default_lang) && $this->wpml_default_lang == $current_lang ){
			if(THWEC_Utils::if_template_file_exists($name)){
				return true;
			}
		}
		return false;
	}

	private function is_a_language_template($name, $current_lang){
		if( !empty($current_lang) && THWEC_Utils::if_template_file_exists($name) ){
			return true;
		}
		return false;
	}
}

endif;

new THWEC_Wpml();