<?php
/**
 * This page manages the integration of YITH gift card plugin.
 *
 * @link       https://themehigh.com
 * @since      3.7.0
 *
 * @package    woocommerce-email-customizer-pro
 * @subpackage woocommerce-email-customizer-pro/admin
 */
if(!defined('WPINC')){	die; }

if(!class_exists('THWEC_Yith_Gift_Card')):

class THWEC_Yith_Gift_Card extends THWEC_Integrations{
	/**
	 * List of WooCommerce order status manager emails
	 *
	 * @access   private
	 * @var      $wosm_emails    array of emails
	 */
    private $ywgc_emails = array();

     /**
	 * Order status manager emails ID and name array
	 *
	 * @access   private
	 * @var      $compatibility_settings    array of ID and name
	 */
    private $compatibility_settings = array();

     /**
	 * Manages the data required to find the current order status manager email
	 *
	 * @access   private
	 * @var      $wc_status_manager_email    order status manager helper
	 */
    private $wc_status_manager_email = array();

	/**
	 * Construct
	 */
	public function __construct() {
		parent::__construct();
		$this->set_ywgc_emails();
		add_filter('thwec_email_statuses', array($this, 'prepare_emails'), 10, 1);
		add_filter('thwec_default_email_subjects', array($this, 'ywgc_subjects'), 10, 1);
		add_filter('woocommerce_email_subject_ywgc-email-delivered-gift-card', array($this, 'thwec_email_subject_ywgc_delivered'), 1, 2);
    	add_filter('woocommerce_email_subject_ywgc-email-notify-customer', array($this, 'thwec_email_subject_ywgc_notify'), 1, 2);
    	add_filter('woocommerce_email_subject_ywgc-email-send-gift-card', array($this, 'thwec_email_subject_ywgc_send'), 1, 2);
    	add_filter('thwec_format_placeholders', array($this, 'is_ywgc_email'), 10, 1);
    	add_filter('thwec_is_ywgc_email', array($this, 'is_ywgc_email'), 10, 2);
		// add_filter('thwec_set_compatibility_settings', array($this, 'wosm_compatibility_settings'), 10, 1);
		// add_filter('wc_order_status_manager_order_status_email_replace_variables', array($this, 'prepare_status_name'), 999, 4);
		add_filter('thwec_locate_integration_template', array($this, 'ywgc_email_mapping'), 10, 4);
		add_filter('thwec_get_script_data', array($this, 'get_script_contents'), 10, 2);
		add_filter( 'thwec_woo_attachment_email_ids', array($this, 'thwec_ywgc_attachment_emails'), 10, 1 );
		add_filter('thwec_woo_email_instances', array($this, 'get_compatible_woo_emails'));

	}

	public function set_ywgc_emails(){
		$this->ywgc_emails = array(
			'ywgc-email-send-gift-card' => 'YITH Gift Cards - Dispatch of the code',
			'ywgc-email-notify-customer' => 'YITH Gift Cards - Customer Notification',
			'ywgc-email-delivered-gift-card' => 'YITH Gift Cards - Delivered Gift Card Notification'
		);
		$this->ywgc_subjects = array(
			'ywgc-email-send-gift-card' 		=> '[{site_name}] You have received a gift card',
			'ywgc-email-notify-customer' 		=> '[{site_name}] Your gift card has been used',
			'ywgc-email-delivered-gift-card' 	=> '[{site_name}] Your gift card has been delivered',
		);
	}

	public function is_ywgc_email($is_email, $status){
		if(array_key_exists($status, $this->ywgc_emails)){
			return true;
		}
		return false;
	}
	public function prepare_emails($emails){
		return array_merge($emails, $this->ywgc_emails);
	}

	public function ywgc_subjects($subjects){
		return array_merge($subjects, $this->ywgc_subjects);
	}

	public function wosm_compatibility_settings($compatibility_settings){
		return $this->compatibility_settings;
	}

	public function ywgc_email_mapping($found, $template_id, $template_name, $map){
		if( $template_name == "emails/send-gift-card.php" && is_array($map) ){
			return isset($map[$template_id]) ? $map[$template_id] : false;
		}
		return $found;
	}

	private function render_subject($id){
		add_filter('woocommerce_email_subject_wc_order_status_email_'.$id, array($this, 'set_subject'), 1, 2);
	}

    public function prepare_status_name( $find, $id, $type, $object ){
		if( !empty( $id ) ){
			$this->wc_status_manager_email['id'] = $id;
		}
		return $find;	
	}

	public function set_subject($subject, $order){
		$id = isset( $this->wc_status_manager_email['id'] ) ? $this->wc_status_manager_email['id'] : false;
    	if( $id && isset( $this->subjects[$id] ) ){
    		$subject = THWEC_Utils::format_subjects( $this->subjects[$id], '', $order );
    	}
    	return $subject;
	}

	public function thwec_wosm_attachments($attachments, $email_id, $order, $email){
    	$email_attachments = isset($this->settings[THWEC_Utils::get_email_attachment_key()]) ? $this->settings[THWEC_Utils::get_email_attachment_key()] : array();
    	$email_attachment = isset($email_attachments[$email_id]) ? $email_attachments[$email_id] : false;
    	if( is_array( $email_attachment ) ){
    		foreach ($email_attachment as $index => $attachment) {
    			if( isset($attachment['file_url']) ){
    				$attachments[] = $attachment['file_url'];
    			}		
    		}
    	}
    	return $attachments;
    }

    /**
	 * Subject for YITH Gift Card delivered notification
	 *
	 * @param  string $subject default email subject
	 * @param  object $order Order
	 * @return string modified subject
	 */	
	public function thwec_email_subject_ywgc_delivered($subject, $order){
		return $this->format_email_subject( $subject, 'ywgc-email-delivered-gift-card', $order );

	}

	/**
	 * Subject for YITH Gift Card customer notification
	 *
	 * @param  string $subject default email subject
	 * @param  object $order Order
	 * @return string modified subject
	 */	
	public function thwec_email_subject_ywgc_notify($subject, $order){
		return $this->format_email_subject( $subject, 'ywgc-email-notify-customer', $order );
	}

	/**
	 * Subject for send YITH Gift Card email
	 *
	 * @param  string $subject default email subject
	 * @param  object $order Order
	 * @return string modified subject
	 */	
	public function thwec_email_subject_ywgc_send($subject, $order){
		return $this->format_email_subject( $subject, 'ywgc-email-send-gift-card', $order );
	}

	public function get_script_contents($script_var, $hook){
		if($hook != "email-customizer_page_th_email_customizer_pro"){
			return $script_var;
		}
		$yith_button_label = get_option ( 'ywgc_email_button_label', esc_html__( 'Apply your gift card code', 'yith-woocommerce-gift-cards' ) );
		$yith_button_label = empty( $yith_button_label ) ? esc_html__( 'Apply your gift card code', 'yith-woocommerce-gift-cards' ) : $yith_button_label;
		$shop_logo = get_option('ywgc_shop_logo_url');
		$header_image = get_option('ywgc_gift_card_header_url');
		$script_var['ywgc_active'] = true;
		$script_var['ywgc_ids'] = $this->get_ywgc_ids();
		$script_var['ywgc_emails'] = array_keys( $this->ywgc_emails );
		$script_var['ywgc'] = array(
        	'display_qr' => get_option( 'ywgc_display_qr_code' , 'no' ),
        	'description' => get_option( 'ywgc_description_template_email_text', esc_html__( "To use this gift card, you can either enter the code in the gift card field on the cart page or click on the following link to automatically get the discount.", 'yith-woocommerce-gift-cards' ) ),
        	'expiration_message' => apply_filters ( 'yith_ywgc_gift_card_email_expiration_message', _x( 'This gift card code will be valid until %s ('.get_option( 'ywgc_plugin_date_format_option', 'yy-mm-dd' ).')', 'gift card expiration date', 'yith-woocommerce-gift-cards' ) ),
        	'discount_button_label' => $yith_button_label,
        	
        	'shop_logo' => $shop_logo ? $shop_logo : YITH_YWGC_ASSETS_IMAGES_URL.'default-giftcard-main-image.jpg',
			'header_image' => $header_image ? $header_image : YITH_YWGC_ASSETS_IMAGES_URL.'default-giftcard-main-image.jpg',
        	'logo_before_gift_card' => get_option( 'ywgc_shop_logo_on_gift_card_before', 'no' ),
        	'logo_before_gift_card_alignment' => get_option( 'ywgc_shop_logo_before_alignment', 'center' ),
        	'logo_after_gift_card' => get_option( 'ywgc_shop_logo_on_gift_card_after', 'no' ),
        	'logo_after_gift_card_alignment' => get_option( 'ywgc_shop_logo_after_alignment', 'center' ),
        );
        return $script_var;
	}

	private function get_ywgc_ids(){
		$gift_cards = array();
		$ywgc_cards = array();
		if( defined( 'YWGC_CUSTOM_POST_TYPE_NAME' ) ){
			$gift_cards = get_posts([
		    	'post_type' => YWGC_CUSTOM_POST_TYPE_NAME,
		    	'post_status' => 'any',
		    	'numberposts' => -1,
			]);
		}
		if( is_array( $gift_cards ) ){
			foreach ($gift_cards as $key => $value) {
				$ywgc_cards[$value->ID] = $value->post_title;
			}
		}
		return $ywgc_cards;
	}

	public function get_compatible_woo_emails($emails){
		$ywgc_emails = $this->ywgc_emails;
		unset($ywgc_emails['ywgc-email-delivered-gift-card']);
  		return array_merge($emails, $ywgc_emails);
	}

	public function thwec_ywgc_attachment_emails($ids){
		return array_merge($ids, array_keys($this->ywgc_subjects));
	}
}

endif;

new THWEC_Yith_Gift_Card();