<?php
/**
 * Plugin Name:       Email Customizer for WooCommerce (Pro)
 * Plugin URI:        https://themehigh.com/product/woocommerce-email-customizer
 * Description:       Add and customize WooCommerce transactional emails with the new drag and drop email builder (Create, edit, and delete email templates).
 * Version:           3.9.0
 * Author:            ThemeHigh
 * Author URI:        https://themehigh.com/
 *
 * Text Domain:       woocommerce-email-customizer-pro
 * Domain Path:       /languages
 * Update URI:		  https://www.themehigh.com/product/woocommerce-email-customizer/
 *
 * WC requires at least: 3.0.0
 * WC tested up to: 7.8
 */

if(!defined('WPINC')){	die; }

/**
 * Check if WooCommerce is active
 */
if (!function_exists('is_woocommerce_active')){
	function is_woocommerce_active(){
	    $active_plugins = (array) get_option('active_plugins', array());
	    if(is_multisite()){
		   $active_plugins = array_merge($active_plugins, get_site_option('active_sitewide_plugins', array()));
	    }
	    return in_array('woocommerce/woocommerce.php', $active_plugins) || array_key_exists('woocommerce/woocommerce.php', $active_plugins);
	}
}

/**
 * Define plugin constants
 */
if(is_woocommerce_active()) {
	define('THWEC_VERSION', '3.9.0');
	!defined('THWEC_SOFTWARE_TITLE') && define('THWEC_SOFTWARE_TITLE', 'WooCommerce Email Customizer');
	!defined('THWEC_FILE') && define('THWEC_FILE', __FILE__);
	!defined('THWEC_PATH') && define('THWEC_PATH', plugin_dir_path( __FILE__ ));
	!defined('THWEC_URL') && define('THWEC_URL', plugins_url( '/', __FILE__ ));
	!defined('THWEC_BASE_NAME') && define('THWEC_BASE_NAME', plugin_basename( __FILE__ ));

	// EDD Params
	!defined('THWEC_STORE_API_URL') && define('THWEC_STORE_API_URL', 'https://www.themehigh.com');
	!defined('THWEC_ITEM_ID') && define('THWEC_ITEM_ID', 22);
	!defined('THWEC_ITEM_NAME') && define('THWEC_ITEM_NAME', 'Email Customizer for WooCommerce (Pro)');
	!defined('THWEC_LICENSE_PAGE_URL') && define('THWEC_LICENSE_PAGE_URL', admin_url('admin.php?page=th_email_customizer_license_settings'));

	
	/**
	 * The code that runs during plugin activation.
	 */
	function activate_thwec() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-thwec-activator.php';
		THWEC_Activator::activate();
	}
	
	/**
	 * The code that runs during plugin deactivation.
	 */
	function deactivate_thwec() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/class-thwec-deactivator.php';
		THWEC_Deactivator::deactivate();
	}
	
	register_activation_hook( __FILE__, 'activate_thwec' );
	register_deactivation_hook( __FILE__, 'deactivate_thwec' );
	
	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/class-thwec.php';
	
	/**
	 * Begins execution of the plugin.
	 */
	function run_thwec() {
		$plugin = new THWEC();
		$plugin->run();
	}
	run_thwec();
}

add_action( 'before_woocommerce_init', 'thwec_before_woocommerce_init' ) ;
function thwec_before_woocommerce_init() {
    if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
    }
}

function thwec_lm_to_edd_license_migration() {
	$edd_license_key = 'th_email_customizer_for_woocommerce_license_data';
	$edd_license_data = get_option($edd_license_key, array());
	if(empty($edd_license_data)){
		$lm_software_title = "WooCommerce Email Customizer";
		$lm_prefix = str_ireplace(array( ' ', '_', '&', '?', '-' ), '_', strtolower($lm_software_title));
		$lm_license_key = $lm_prefix . '_thlmdata';
		$lm_license_data = get_thlm_thwec_saved_license_data($lm_license_key);
		if($lm_license_data){
			$status = isset($lm_license_data['status']) ? $lm_license_data['status'] : '';
			if($status = 'active'){
				$new_data = array(
					'license_key' => isset($lm_license_data['license_key']) ? $lm_license_data['license_key'] : '',
					'expiry' => isset($lm_license_data['expiry_date']) ? $lm_license_data['expiry_date'] : '',
					'status' => 'valid',
				);
				$result = update_thwec_edd_license_data($edd_license_key, $new_data);
				if($result){
					delete_thwec_lm_license_data($lm_license_key);
				}
			}
		}
	}
	
}
add_action( 'admin_init', 'thwec_lm_to_edd_license_migration' );

function get_thlm_thwec_saved_license_data($key){
	$license_data = '';
	if(is_multisite()){
		$license_data = get_site_option($key);
	}else{
		$license_data = get_option($key);
	}
	return $license_data;
}

function update_thwec_edd_license_data($edd_license_key, $data){
	$result = false;
	if(is_multisite()){
		$result = update_site_option($edd_license_key, $data, 'no');
	}else{
		$result = update_option($edd_license_key, $data, 'no');
	}
	return $result;
}

function delete_thwec_lm_license_data($key){
	if(is_multisite()){
		delete_site_option($key);
	}else{
		delete_option($key);
	}
}

if(!class_exists('THWEC_EDD_Updater_Helper') ) {
	require_once( plugin_dir_path( __FILE__ ) . 'class-thwec-updater-helper.php' );
}

if (!class_exists( 'THWEC_EDD_Updater' ) ) {
	require_once( plugin_dir_path( __FILE__ ) . '/class-thwec-updater.php' );
}

function init_thwec_updater_helper(){

	$helper_data = array(
		'api_url' => THWEC_STORE_API_URL, 			  // API URL
		'item_id' => THWEC_ITEM_ID, 				  // Product id
		'product_name' => THWEC_ITEM_NAME, 			  // Product name
		'license_page_url' => THWEC_LICENSE_PAGE_URL, // License page URL
		'admin_asset_url' => THWEC_URL . 'admin/assets/', // Asset URL for Admin
	);

	$thwec_updater_helper = THWEC_EDD_Updater_Helper::instance(__FILE__, $helper_data);

	/**
	 * Initialize the updater. Hooked into `init` to work with the
	 * wp_version_check cron job, which allows auto-updates.
	 */

	// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
	$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
	if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
		return;
	}

	// retrieve our license key from the DB
	$license_data = $thwec_updater_helper->get_license_data();
	$license_key = isset($license_data['license_key']) ? $license_data['license_key'] : false;

	// setup the updater
	$edd_updater = new THWEC_EDD_Updater(
		THWEC_STORE_API_URL,
		__FILE__,
		array(
			'version' => THWEC_VERSION,     // version number
			'license' => $license_key,      // license key 
			'item_id' => THWEC_ITEM_ID,     // ID of the product
			'author'  => 'ThemeHigh',		// author of this plugin
			'beta'    => false,
		)
	);

}


add_action( 'init', 'init_thwec_updater_helper', 10 );